<?php
// Add Home Page Banner Section.
$wp_customize->add_section(
	'home_banner_options',
	array(
		'title' => __( 'Banner Options', 'magazine-elite' ),
		'panel' => 'theme_home_option_panel',
	)
);

// Enable Banner Section.
$wp_customize->add_setting(
	'enable_banner',
	array(
		'default'           => $theme_options_defaults['enable_banner'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner',
		array(
			'label'   => __( 'Enable Home Banner', 'magazine-elite' ),
			'section' => 'home_banner_options',
		)
	)
);

// Banner section background.
$wp_customize->add_setting(
	'banner_section_bg_color',
	array(
		'default'           => $theme_options_defaults['banner_section_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'banner_section_bg_color',
		array(
			'label'           => __( 'Banner Section Background', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'type'            => 'color',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Banner Title.
$wp_customize->add_setting(
	'banner_title',
	array(
		'default'           => $theme_options_defaults['banner_title'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'banner_title',
	array(
		'label'           => __( 'Banner Title', 'magazine-elite' ),
		'description'     => __( 'Leave empty if you don\'t want to show the title.', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'text',
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Title Style.
$wp_customize->add_setting(
	'banner_title_style',
	array(
		'default'           => $theme_options_defaults['banner_title_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_title_style',
	array(
		'label'           => __( 'Banner Title Style', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_styles(),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Title Align.
$wp_customize->add_setting(
	'banner_title_align',
	array(
		'default'           => $theme_options_defaults['banner_title_align'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_title_align',
	array(
		'label'           => __( 'Banner Title Alignment', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_alignments(),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Layout.
$wp_customize->add_setting(
	'banner_layout',
	array(
		'default'           => $theme_options_defaults['banner_layout'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_layout',
	array(
		'label'           => __( 'Banner Layout', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'full-width' => __( 'FullWidth', 'magazine-elite' ),
			'boxed'      => __( 'Boxed', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Display as slider/carousel.
$wp_customize->add_setting(
	'banner_display_as',
	array(
		'default'           => $theme_options_defaults['banner_display_as'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_display_as',
	array(
		'label'           => __( 'Banner Display As', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'slider'   => __( 'Slider', 'magazine-elite' ),
			'carousel' => __( 'Carousel', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Content from ids or category.
$wp_customize->add_setting(
	'banner_content_from',
	array(
		'default'           => $theme_options_defaults['banner_content_from'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_content_from',
	array(
		'label'           => __( 'Get Banner Content From', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'category' => __( 'Category', 'magazine-elite' ),
			'post_ids' => __( 'Post ID\'s', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Banner Post Category.
$wp_customize->add_setting(
	'slider_cat',
	array(
		'default'           => $theme_options_defaults['slider_cat'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Dropdown_Taxonomies_Control(
		$wp_customize,
		'slider_cat',
		array(
			'label'           => __( 'Choose Category', 'magazine-elite' ),
			'description'     => __( 'Leave Empty if you don\'t want the posts to be category specific', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_home_banner_enabled( $control )
					&&
					magazine_elite_banner_content_from_category( $control )
				);
			},
		)
	)
);

// No of posts.
$wp_customize->add_setting(
	'no_of_banner_posts',
	array(
		'default'           => $theme_options_defaults['no_of_banner_posts'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'no_of_banner_posts',
	array(
		'label'           => __( 'Number of Posts', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'number',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_banner_content_from_category( $control )
			);
		},
	)
);

// Posts Orderby.
$wp_customize->add_setting(
	'banner_posts_orderby',
	array(
		'default'           => $theme_options_defaults['banner_posts_orderby'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_posts_orderby',
	array(
		'label'           => __( 'Orderby', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'date'  => __( 'Date', 'magazine-elite' ),
			'id'    => __( 'ID', 'magazine-elite' ),
			'title' => __( 'Title', 'magazine-elite' ),
			'rand'  => __( 'Random', 'magazine-elite' ),
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_banner_content_from_category( $control )
			);
		},
	)
);

// Posts Order.
$wp_customize->add_setting(
	'banner_posts_order',
	array(
		'default'           => $theme_options_defaults['banner_posts_order'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_posts_order',
	array(
		'label'           => __( 'Order', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'asc'  => __( 'ASC', 'magazine-elite' ),
			'desc' => __( 'DESC', 'magazine-elite' ),
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_banner_content_from_category( $control )
			);
		},
	)
);

// Banner Post IDs.
$wp_customize->add_setting(
	'banner_post_ids',
	array(
		'default'           => $theme_options_defaults['banner_post_ids'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'banner_post_ids',
	array(
		'label'           => __( 'Post ID\'s', 'magazine-elite' ),
		'description'     => __( 'Comma ( , ) separated posts ids. Ex: 1, 2, 3', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'text',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_banner_content_from_post_ids( $control )
			);
		},
	)
);

// Enable Banner Autoplay.
$wp_customize->add_setting(
	'enable_banner_autoplay',
	array(
		'default'           => $theme_options_defaults['enable_banner_autoplay'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_autoplay',
		array(
			'label'           => __( 'Enable Banner Autoplay', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Enable Banner Arrows.
$wp_customize->add_setting(
	'enable_banner_arrows',
	array(
		'default'           => $theme_options_defaults['enable_banner_arrows'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_arrows',
		array(
			'label'           => __( 'Enable Banner Arrows', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Banner Arrows background.
$wp_customize->add_setting(
	'banner_arrows_bg_color',
	array(
		'default'           => $theme_options_defaults['banner_arrows_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'banner_arrows_bg_color',
		array(
			'label'           => __( 'Banner Arrows Background', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_home_banner_enabled( $control )
					&&
					magazine_elite_is_home_banner_arrows_enabled( $control )
				);
			},
		)
	)
);

// Enable Banner Dots.
$wp_customize->add_setting(
	'enable_banner_dots',
	array(
		'default'           => $theme_options_defaults['enable_banner_dots'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_dots',
		array(
			'label'           => __( 'Enable Banner Dots', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Enable Banner Thumbnail Navigation.
$wp_customize->add_setting(
	'enable_banner_thumb_nav',
	array(
		'default'           => $theme_options_defaults['enable_banner_thumb_nav'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_thumb_nav',
		array(
			'label'           => __( 'Enable Banner Thumbnail Navigation', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_home_banner_enabled( $control )
					&&
					magazine_elite_is_home_banner_as_slider( $control )
				);
			},
		)
	)
);

// Enable Banner Overlay.
$wp_customize->add_setting(
	'enable_banner_overlay',
	array(
		'default'           => $theme_options_defaults['enable_banner_overlay'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_overlay',
		array(
			'label'           => __( 'Show Banner Overlay', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Banner overlay color.
$wp_customize->add_setting(
	'banner_overlay_color',
	array(
		'default'           => $theme_options_defaults['banner_overlay_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'banner_overlay_color',
		array(
			'label'           => __( 'Overlay Color', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_home_banner_enabled( $control )
					&&
					magazine_elite_is_banner_overlay_enabled( $control )
				);
			},
		)
	)
);

// Banner Overlay Opacity.
$wp_customize->add_setting(
	'banner_overlay_opacity',
	array(
		'default'           => $theme_options_defaults['banner_overlay_opacity'],
		'sanitize_callback' => 'magazine_elite_sanitize_float',
	)
);
$wp_customize->add_control(
	'banner_overlay_opacity',
	array(
		'label'           => __( 'Overlay Opacity', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'number',
		'input_attrs'     => array(
			'min'   => 0,
			'max'   => 1,
			'step'  => 0.1,
			'style' => 'width: 150px;',
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_is_banner_overlay_enabled( $control )
			);
		},
	)
);

// Show Banner Category.
$wp_customize->add_setting(
	'show_banner_category',
	array(
		'default'           => $theme_options_defaults['show_banner_category'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_banner_category',
		array(
			'label'           => __( 'Show Banner Category', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Banner Category Color Display.
$wp_customize->add_setting(
	'banner_category_color_display',
	array(
		'default'           => $theme_options_defaults['banner_category_color_display'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_category_color_display',
	array(
		'label'           => __( 'Banner Category Color Display', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_category_color_display(),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_is_banner_category_enabled( $control )
			);
		},
	)
);

// Banner Category Style.
$wp_customize->add_setting(
	'banner_category_style',
	array(
		'default'           => $theme_options_defaults['banner_category_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_category_style',
	array(
		'label'           => __( 'Banner Category Style', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_category_styles(),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_is_banner_category_enabled( $control )
			);
		},
	)
);

// No of Banner Categories.
$wp_customize->add_setting(
	'banner_category_limit',
	array(
		'default'           => $theme_options_defaults['banner_category_limit'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'banner_category_limit',
	array(
		'label'           => __( 'Number of Categories To Display', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'number',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_home_banner_enabled( $control )
				&&
				magazine_elite_is_banner_category_enabled( $control )
			);
		},
	)
);

/* Banner Posts Meta */
$wp_customize->add_setting(
	'banner_post_meta',
	array(
		'default'           => $theme_options_defaults['banner_post_meta'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox_multiple',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Checkbox_Multiple(
		$wp_customize,
		'banner_post_meta',
		array(
			'label'           => __( 'Banner Post Meta', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'choices'         => array(
				'author'    => __( 'Author', 'magazine-elite' ),
				'read_time' => __( 'Post Read Time', 'magazine-elite' ),
				'date'      => __( 'Date', 'magazine-elite' ),
				'comment'   => __( 'Comment', 'magazine-elite' ),
			),
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Banner Date Format
$wp_customize->add_setting(
	'banner_posts_date_format',
	array(
		'default'           => $theme_options_defaults['banner_posts_date_format'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_posts_date_format',
	array(
		'label'           => __( 'Date Format', 'magazine-elite' ),
		'description'     => __( 'Make sure to enable Date post meta from above for this to work.', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => array(
			'format_1' => __( 'Times Ago', 'magazine-elite' ),
			'format_2' => __( 'Default Format', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);

// Show Banner author image.
$wp_customize->add_setting(
	'enable_banner_author_image',
	array(
		'default'           => $theme_options_defaults['enable_banner_author_image'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_banner_author_image',
		array(
			'label'           => __( 'Show Author Image', 'magazine-elite' ),
			'description'     => __( 'Make sure to enable Author post meta from above for this to work.', 'magazine-elite' ),
			'section'         => 'home_banner_options',
			'active_callback' => 'magazine_elite_is_home_banner_enabled',
		)
	)
);

// Post Title Limit.
$wp_customize->add_setting(
	'banner_posts_title_limit',
	array(
		'default'           => '',
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'banner_posts_title_limit',
	array(
		'label'           => __( 'Post Title Limit', 'magazine-elite' ),
		'section'         => 'home_banner_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_limit_choices(),
		'active_callback' => 'magazine_elite_is_home_banner_enabled',
	)
);
