<?php
// Featured categories Options.
$wp_customize->add_section(
	'home_page_featured_categories_options',
	array(
		'title' => __( 'Featured Categories Options', 'magazine-elite' ),
		'panel' => 'theme_home_option_panel',
	)
);

// Enable Featured categories.
$wp_customize->add_setting(
	'enable_featured_categories',
	array(
		'default'           => $theme_options_defaults['enable_featured_categories'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_categories',
		array(
			'label'   => __( 'Enable Featured categories', 'magazine-elite' ),
			'section' => 'home_page_featured_categories_options',
		)
	)
);


// Section background.
$wp_customize->add_setting(
	'featured_categories_section_bg_color',
	array(
		'default'           => $theme_options_defaults['featured_categories_section_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'featured_categories_section_bg_color',
		array(
			'label'           => __( 'Section Background', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'type'            => 'color',
			'active_callback' => 'magazine_elite_is_featured_categories_enabled',
		)
	)
);

// Section Title.
$wp_customize->add_setting(
	'featured_categories_title',
	array(
		'default'           => $theme_options_defaults['featured_categories_title'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'featured_categories_title',
	array(
		'label'           => __( 'Section Title', 'magazine-elite' ),
		'description'     => __( 'Leave empty if you don\'t want to show the title.', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'text',
		'active_callback' => 'magazine_elite_is_featured_categories_enabled',
	)
);

// Section Title Style.
$wp_customize->add_setting(
	'featured_categories_title_style',
	array(
		'default'           => $theme_options_defaults['featured_categories_title_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_categories_title_style',
	array(
		'label'           => __( 'Section Title Style', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_styles(),
		'active_callback' => 'magazine_elite_is_featured_categories_enabled',
	)
);

// Section Title Align.
$wp_customize->add_setting(
	'featured_categories_title_align',
	array(
		'default'           => $theme_options_defaults['featured_categories_title_align'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_categories_title_align',
	array(
		'label'           => __( 'Section Title Alignment', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_alignments(),
		'active_callback' => 'magazine_elite_is_featured_categories_enabled',
	)
);

// Section Column.
$wp_customize->add_setting(
	'featured_categories_column',
	array(
		'default'           => $theme_options_defaults['featured_categories_column'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_categories_column',
	array(
		'label'           => __( 'Column', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'select',
		'choices'         => array(
			'2' => __( '2', 'magazine-elite' ),
			'3' => __( '3', 'magazine-elite' ),
			'4' => __( '4', 'magazine-elite' ),
			'5' => __( '5', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_featured_categories_enabled',
	)
);

// Featured Categories.
$wp_customize->add_setting(
	'featured_categories',
	array(
		'default'           => '',
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox_multiple',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Checkbox_Taxonomies_Control(
		$wp_customize,
		'featured_categories',
		array(
			'label'           => __( 'Choose Categories', 'magazine-elite' ),
			'description'     => __( 'You can upload category images when editing indiviudal category.', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'active_callback' => 'magazine_elite_is_featured_categories_enabled',
		)
	)
);

// Enable Description.
$wp_customize->add_setting(
	'enable_featured_categories_desc',
	array(
		'default'           => $theme_options_defaults['enable_featured_categories_desc'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_categories_desc',
		array(
			'label'           => __( 'Enable Categories Description', 'magazine-elite' ),
			'description'     => __( 'You can add category description when editing indiviudal category.', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'active_callback' => 'magazine_elite_is_featured_categories_enabled',
		)
	)
);

// Description Length.
$wp_customize->add_setting(
	'featured_categories_desc_length',
	array(
		'default'           => $theme_options_defaults['featured_categories_desc_length'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'featured_categories_desc_length',
	array(
		'label'           => __( 'Description Length', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'number',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_categories_enabled( $control )
				&&
				magazine_elite_is_featured_categories_desc_enabled( $control )
			);
		},
	)
);

// Enable Read More.
$wp_customize->add_setting(
	'enable_featured_categories_read_more',
	array(
		'default'           => $theme_options_defaults['enable_featured_categories_read_more'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_categories_read_more',
		array(
			'label'           => __( 'Enable Read More', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_featured_categories_enabled( $control )
					&&
					magazine_elite_is_featured_categories_desc_enabled( $control )
				);
			},
		)
	)
);

/* Read More Text */
$wp_customize->add_setting(
	'featured_categories_read_more_text',
	array(
		'default'           => $theme_options_defaults['featured_categories_read_more_text'],
		'sanitize_callback' => 'wp_filter_nohtml_kses',
	)
);
$wp_customize->add_control(
	'featured_categories_read_more_text',
	array(
		'label'           => __( 'Read More Text', 'magazine-elite' ),
		'description'     => __( 'Leave empty if you want to use default text "Find out more".', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'text',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_categories_enabled( $control )
				&&
				magazine_elite_is_featured_categories_desc_enabled( $control )
				&&
				magazine_elite_is_featured_categories_read_more_enabled( $control )
			);
		},
	)
);

// Read More Icon.
$wp_customize->add_setting(
	'featured_categories_read_more_icon',
	array(
		'default'           => $theme_options_defaults['featured_categories_read_more_icon'],
		'sanitize_callback' => 'magazine_elite_sanitize_radio',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Radio_Image_Control(
		$wp_customize,
		'featured_categories_read_more_icon',
		array(
			'label'           => __( 'Read More Icon', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'choices'         => array(
				'arrow-bar-right'         => array(
					'url'   => get_template_directory_uri() . '/assets/images/arrow-bar-right.svg',
					'label' => esc_html__( 'Arrow Bar Right', 'magazine-elite' ),
				),
				'arrow-right'             => array(
					'url'   => get_template_directory_uri() . '/assets/images/arrow-right.svg',
					'label' => esc_html__( 'Arrow Right', 'magazine-elite' ),
				),
				'arrow-right-circle'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/arrow-right-circle.svg',
					'label' => esc_html__( 'Arrow Right Circle', 'magazine-elite' ),
				),
				'arrow-right-circle-fill' => array(
					'url'   => get_template_directory_uri() . '/assets/images/arrow-right-circle-fill.svg',
					'label' => esc_html__( 'Arrow Right Circle Fill', 'magazine-elite' ),
				),
				'chevron-right'           => array(
					'url'   => get_template_directory_uri() . '/assets/images/chevron-right.svg',
					'label' => esc_html__( 'Chevron Right', 'magazine-elite' ),
				),
				'chevron-double-right'    => array(
					'url'   => get_template_directory_uri() . '/assets/images/chevron-double-right.svg',
					'label' => esc_html__( 'Chevron Double Right', 'magazine-elite' ),
				),
				'caret-right'             => array(
					'url'   => get_template_directory_uri() . '/assets/images/caret-right.svg',
					'label' => esc_html__( 'Caret Right', 'magazine-elite' ),
				),
				'caret-right-fill'        => array(
					'url'   => get_template_directory_uri() . '/assets/images/caret-right-fill.svg',
					'label' => esc_html__( 'Caret Right Fill', 'magazine-elite' ),
				),
			),
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_featured_categories_enabled( $control )
					&&
					magazine_elite_is_featured_categories_desc_enabled( $control )
					&&
					magazine_elite_is_featured_categories_read_more_enabled( $control )
				);
			},
		)
	)
);

// Description Display.
$wp_customize->add_setting(
	'featured_categories_desc_display',
	array(
		'default'           => $theme_options_defaults['featured_categories_desc_display'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_categories_desc_display',
	array(
		'label'           => __( 'Description Display', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'select',
		'choices'         => array(
			'style_1' => __( 'Style 1', 'magazine-elite' ),
			'style_2' => __( 'Style 2', 'magazine-elite' ),
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_categories_enabled( $control )
				&&
				magazine_elite_is_featured_categories_desc_enabled( $control )
			);
		},
	)
);

// Enable Overlay.
$wp_customize->add_setting(
	'enable_featured_categories_overlay',
	array(
		'default'           => $theme_options_defaults['enable_featured_categories_overlay'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_categories_overlay',
		array(
			'label'           => __( 'Show Overlay', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'active_callback' => 'magazine_elite_is_featured_categories_enabled',
		)
	)
);

// Overlay color.
$wp_customize->add_setting(
	'featured_categories_overlay_color',
	array(
		'default'           => $theme_options_defaults['featured_categories_overlay_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'featured_categories_overlay_color',
		array(
			'label'           => __( 'Overlay Color', 'magazine-elite' ),
			'section'         => 'home_page_featured_categories_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_featured_categories_enabled( $control )
					&&
					magazine_elite_is_featured_categories_overlay_enabled( $control )
				);
			},
		)
	)
);

// Overlay Opacity.
$wp_customize->add_setting(
	'featured_categories_overlay_opacity',
	array(
		'default'           => $theme_options_defaults['featured_categories_overlay_opacity'],
		'sanitize_callback' => 'magazine_elite_sanitize_float',
	)
);
$wp_customize->add_control(
	'featured_categories_overlay_opacity',
	array(
		'label'           => __( 'Overlay Opacity', 'magazine-elite' ),
		'section'         => 'home_page_featured_categories_options',
		'type'            => 'number',
		'input_attrs'     => array(
			'min'   => 0,
			'max'   => 1,
			'step'  => 0.1,
			'style' => 'width: 150px;',
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_categories_enabled( $control )
				&&
				magazine_elite_is_featured_categories_overlay_enabled( $control )
			);
		},
	)
);
