<?php
// Featured Posts Options.
$wp_customize->add_section(
	'home_page_featured_posts_options',
	array(
		'title' => __( 'Featured Post Options', 'magazine-elite' ),
		'panel' => 'theme_home_option_panel',
	)
);

// Enable Featured Posts.
$wp_customize->add_setting(
	'enable_featured_posts',
	array(
		'default'           => $theme_options_defaults['enable_featured_posts'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_posts',
		array(
			'label'   => __( 'Enable Featured Posts', 'magazine-elite' ),
			'section' => 'home_page_featured_posts_options',
		)
	)
);

// Featured section background.
$wp_customize->add_setting(
	'featured_section_bg_color',
	array(
		'default'           => $theme_options_defaults['featured_section_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'featured_section_bg_color',
		array(
			'label'           => __( 'Featured Section Background', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'type'            => 'color',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Posts Title.
$wp_customize->add_setting(
	'featured_posts_title',
	array(
		'default'           => $theme_options_defaults['featured_posts_title'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'featured_posts_title',
	array(
		'label'           => __( 'Featured Section Title', 'magazine-elite' ),
		'description'     => __( 'Leave empty if you don\'t want to show the title.', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'text',
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Featured Post Title Style.
$wp_customize->add_setting(
	'featured_posts_title_style',
	array(
		'default'           => $theme_options_defaults['featured_posts_title_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_title_style',
	array(
		'label'           => __( 'Featured Section Title Style', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_styles(),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Featured Post Title Align.
$wp_customize->add_setting(
	'featured_posts_title_align',
	array(
		'default'           => $theme_options_defaults['featured_posts_title_align'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_title_align',
	array(
		'label'           => __( 'Featured Section Title Alignment', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_alignments(),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Featured Post Column.
$wp_customize->add_setting(
	'featured_posts_column',
	array(
		'default'           => $theme_options_defaults['featured_posts_column'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_column',
	array(
		'label'           => __( 'Featured Post Column', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => array(
			'2' => __( '2', 'magazine-elite' ),
			'3' => __( '3', 'magazine-elite' ),
			'4' => __( '4', 'magazine-elite' ),
			'5' => __( '5', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Featured Posts Category.
$wp_customize->add_setting(
	'featured_posts_cat',
	array(
		'default'           => $theme_options_defaults['featured_posts_cat'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Dropdown_Taxonomies_Control(
		$wp_customize,
		'featured_posts_cat',
		array(
			'label'           => __( 'Choose Featured posts category', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Enable Featured Posts View All.
$wp_customize->add_setting(
	'enable_featured_posts_view_all',
	array(
		'default'           => $theme_options_defaults['enable_featured_posts_view_all'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_posts_view_all',
		array(
			'label'   => __( 'Enable View all', 'magazine-elite' ),
			'section' => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Posts View All Text.
$wp_customize->add_setting(
	'featured_posts_view_all_txt',
	array(
		'default'           => $theme_options_defaults['featured_posts_view_all_txt'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'featured_posts_view_all_txt',
	array(
		'label'           => __( 'View All Text', 'magazine-elite' ),
		'description'     => __( 'Leave empty if you want to use the default text "View All".', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'text',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_posts_view_all_enabled( $control )
			);
		},
	)
);

// No of posts.
$wp_customize->add_setting(
	'no_of_featured_posts',
	array(
		'default'           => $theme_options_defaults['no_of_featured_posts'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'no_of_featured_posts',
	array(
		'label'           => __( 'Number of Posts', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'number',
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Posts Orderby.
$wp_customize->add_setting(
	'featured_posts_orderby',
	array(
		'default'           => $theme_options_defaults['featured_posts_orderby'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_orderby',
	array(
		'label'           => __( 'Orderby', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => array(
			'date'  => __( 'Date', 'magazine-elite' ),
			'id'    => __( 'ID', 'magazine-elite' ),
			'title' => __( 'Title', 'magazine-elite' ),
			'rand'  => __( 'Random', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Posts Order.
$wp_customize->add_setting(
	'featured_posts_order',
	array(
		'default'           => $theme_options_defaults['featured_posts_order'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_order',
	array(
		'label'           => __( 'Order', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => array(
			'asc'  => __( 'ASC', 'magazine-elite' ),
			'desc' => __( 'DESC', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Enable Post Description.
$wp_customize->add_setting(
	'enable_featured_posts_desc',
	array(
		'default'           => $theme_options_defaults['enable_featured_posts_desc'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_posts_desc',
		array(
			'label'           => __( 'Enable Post Excerpt', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Post Description Length.
$wp_customize->add_setting(
	'featured_posts_desc_length',
	array(
		'default'           => $theme_options_defaults['featured_posts_desc_length'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'featured_posts_desc_length',
	array(
		'label'           => __( 'Excerpt Length', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'number',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_posts_desc_enabled( $control )
			);
		},
	)
);

// Enable Featured Posts Overlay.
$wp_customize->add_setting(
	'enable_featured_posts_overlay',
	array(
		'default'           => $theme_options_defaults['enable_featured_posts_overlay'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_posts_overlay',
		array(
			'label'           => __( 'Show Featured Posts Overlay', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Posts overlay color.
$wp_customize->add_setting(
	'featured_posts_overlay_color',
	array(
		'default'           => $theme_options_defaults['featured_posts_overlay_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'featured_posts_overlay_color',
		array(
			'label'           => __( 'Overlay Color', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_featured_posts_enabled( $control )
					&&
					magazine_elite_is_featured_overlay_enabled( $control )
				);
			},
		)
	)
);

// Featured Post Overlay Opacity.
$wp_customize->add_setting(
	'featured_posts_overlay_opacity',
	array(
		'default'           => $theme_options_defaults['featured_posts_overlay_opacity'],
		'sanitize_callback' => 'magazine_elite_sanitize_float',
	)
);
$wp_customize->add_control(
	'featured_posts_overlay_opacity',
	array(
		'label'           => __( 'Overlay Opacity', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'number',
		'input_attrs'     => array(
			'min'   => 0,
			'max'   => 1,
			'step'  => 0.1,
			'style' => 'width: 150px;',
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_overlay_enabled( $control )
			);
		},
	)
);

// Show Featured Post Category.
$wp_customize->add_setting(
	'show_featured_posts_category',
	array(
		'default'           => $theme_options_defaults['show_featured_posts_category'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_featured_posts_category',
		array(
			'label'           => __( 'Show Featured Post Category', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Posts Category Color Display.
$wp_customize->add_setting(
	'featured_posts_category_color_display',
	array(
		'default'           => $theme_options_defaults['featured_posts_category_color_display'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_category_color_display',
	array(
		'label'           => __( 'Featured Posts Category Color Display', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_category_color_display(),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_posts_category_enabled( $control )
			);
		},
	)
);

// Featured Post Category Style.
$wp_customize->add_setting(
	'featured_posts_category_style',
	array(
		'default'           => $theme_options_defaults['featured_posts_category_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_category_style',
	array(
		'label'           => __( 'Featured Post Category Style', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_category_styles(),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_posts_category_enabled( $control )
			);
		},
	)
);

// No of Featured Post Categories.
$wp_customize->add_setting(
	'featured_posts_category_limit',
	array(
		'default'           => $theme_options_defaults['featured_posts_category_limit'],
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	'featured_posts_category_limit',
	array(
		'label'           => __( 'Number of Categories To Display', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'number',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_featured_posts_enabled( $control )
				&&
				magazine_elite_is_featured_posts_category_enabled( $control )
			);
		},
	)
);

/* Featured Post Meta */
$wp_customize->add_setting(
	'featured_post_meta',
	array(
		'default'           => $theme_options_defaults['featured_post_meta'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox_multiple',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Checkbox_Multiple(
		$wp_customize,
		'featured_post_meta',
		array(
			'label'           => __( 'Featured Post Meta', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'choices'         => array(
				'author'    => __( 'Author', 'magazine-elite' ),
				'read_time' => __( 'Post Read Time', 'magazine-elite' ),
				'date'      => __( 'Date', 'magazine-elite' ),
				'comment'   => __( 'Comment', 'magazine-elite' ),
			),
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Post Date Format.
$wp_customize->add_setting(
	'featured_posts_date_format',
	array(
		'default'           => $theme_options_defaults['featured_posts_date_format'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_date_format',
	array(
		'label'           => __( 'Date Format', 'magazine-elite' ),
		'description'     => __( 'Make sure to enable Date post meta from above for this to work.', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => array(
			'format_1' => __( 'Times Ago', 'magazine-elite' ),
			'format_2' => __( 'Default Format', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Show Featured Post author image.
$wp_customize->add_setting(
	'enable_featured_posts_author_image',
	array(
		'default'           => $theme_options_defaults['enable_featured_posts_author_image'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'enable_featured_posts_author_image',
		array(
			'label'           => __( 'Show Author Image', 'magazine-elite' ),
			'description'     => __( 'Make sure to enable Author post meta from above for this to work.', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);

// Featured Post Title Limit.
$wp_customize->add_setting(
	'featured_posts_title_limit',
	array(
		'default'           => '',
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'featured_posts_title_limit',
	array(
		'label'           => __( 'Post Title Limit', 'magazine-elite' ),
		'section'         => 'home_page_featured_posts_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_title_limit_choices(),
		'active_callback' => 'magazine_elite_is_featured_posts_enabled',
	)
);

// Show Post Format Icons.
$wp_customize->add_setting(
	'show_featured_posts_post_format_icon',
	array(
		'default'           => $theme_options_defaults['show_featured_posts_post_format_icon'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_featured_posts_post_format_icon',
		array(
			'label'           => __( 'Show Post Format Icon', 'magazine-elite' ),
			'section'         => 'home_page_featured_posts_options',
			'active_callback' => 'magazine_elite_is_featured_posts_enabled',
		)
	)
);
