<?php
$wp_customize->add_section(
	'accessbar_options',
	array(
		'title' => __( 'Accessbar Options', 'magazine-elite' ),
		'panel' => 'misc_options_panel',
	)
);

// Show accessbar.
$wp_customize->add_setting(
	'show_access_bar',
	array(
		'default'           => $theme_options_defaults['show_access_bar'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar',
		array(
			'label'   => __( 'Enable accessbar', 'magazine-elite' ),
			'section' => 'accessbar_options',
		)
	)
);

// Accessbar Theme.
$wp_customize->add_setting(
	'accessbar_theme',
	array(
		'default'           => $theme_options_defaults['accessbar_theme'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'accessbar_theme',
	array(
		'label'    => __( 'Accessbar Theme', 'magazine-elite' ),
		'section'  => 'accessbar_options',
		'type'     => 'select',
		'choices'  => array(
			'light' => __( 'Light', 'magazine-elite' ),
			'dark'  => __( 'Dark', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_accessbar_enabled',
	)
);

// Background Color.
$wp_customize->add_setting(
	'accessbar_bg_color',
	array(
		'default'           => $theme_options_defaults['accessbar_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'accessbar_bg_color',
		array(
			'label'    => __( 'Light Theme Background', 'magazine-elite' ),
			'section'  => 'accessbar_options',
			'type'     => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_accessbar_enabled( $control )
					&&
					magazine_elite_is_light_accessbar( $control )
				);
			},
		)
	)
);

// Dark Theme Background Color.
$wp_customize->add_setting(
	'dark_accessbar_bg_color',
	array(
		'default'           => $theme_options_defaults['dark_accessbar_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'dark_accessbar_bg_color',
		array(
			'label'    => __( 'Dark Theme Background', 'magazine-elite' ),
			'section'  => 'accessbar_options',
			'type'     => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_accessbar_enabled( $control )
					&&
					magazine_elite_is_dark_accessbar( $control )
				);
			},
		)
	)
);

// Accessbar Position.
$wp_customize->add_setting(
	'access_bar_pos',
	array(
		'default'           => $theme_options_defaults['access_bar_pos'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'access_bar_pos',
	array(
		'label'           => __( 'Accessbar Position', 'magazine-elite' ),
		'section'         => 'accessbar_options',
		'type'            => 'select',
		'choices'         => array(
			'left'  => __( 'Left', 'magazine-elite' ),
			'right' => __( 'Right', 'magazine-elite' ),
		),
		'active_callback' => 'magazine_elite_is_accessbar_enabled',
	)
);

// Show Offcanvas.
$wp_customize->add_setting(
	'show_access_bar_offcanvas',
	array(
		'default'           => $theme_options_defaults['show_access_bar_offcanvas'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar_offcanvas',
		array(
			'label'           => __( 'Enable Offcanvas Icon', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

// Show Search.
$wp_customize->add_setting(
	'show_access_bar_search',
	array(
		'default'           => $theme_options_defaults['show_access_bar_search'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar_search',
		array(
			'label'           => __( 'Enable Search Icon', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

/*Enable Social Nav*/
$wp_customize->add_setting(
	'show_access_bar_social_nav',
	array(
		'default'           => $theme_options_defaults['show_access_bar_social_nav'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar_social_nav',
		array(
			'label'           => __( 'Enable Social Nav Menu', 'magazine-elite' ),
			'description'     => sprintf( __( 'You can add/edit social nav menu from <a href="%s">here</a>.', 'magazine-elite' ), "javascript:wp.customize.control( 'nav_menu_locations[social-menu]' ).focus();" ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

// Social Links Brand Color.
$wp_customize->add_setting(
	'access_bar_social_links_color_as',
	array(
		'default'           => $theme_options_defaults['access_bar_social_links_color_as'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'access_bar_social_links_color_as',
	array(
		'label'           => __( 'Social Menu Brand Color', 'magazine-elite' ),
		'section'         => 'accessbar_options',
		'type'            => 'select',
		'choices'         => array(
			'theme_color' => __( 'Use Theme Color', 'magazine-elite' ),
			'brand_color' => __( 'Use Brand Color', 'magazine-elite' ),
		),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_accessbar_enabled( $control )
				&&
				magazine_elite_is_accessbar_social_links_enabled( $control )
			);
		},
	)
);

// Social Icons Color
$wp_customize->add_setting(
	'access_bar_social_links_icons_color',
	array(
		'default'           => $theme_options_defaults['access_bar_social_links_icons_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'access_bar_social_links_icons_color',
		array(
			'label'           => __( 'Social Menu Icons Color', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_accessbar_enabled( $control )
					&&
					magazine_elite_is_accessbar_social_links_enabled( $control )
					&&
					magazine_elite_is_access_bar_social_icons_theme_color( $control )
				);
			},
		)
	)
);

// Social Icons Hover Color
$wp_customize->add_setting(
	'access_bar_social_links_icons_hover_color',
	array(
		'default'           => $theme_options_defaults['access_bar_social_links_icons_hover_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'access_bar_social_links_icons_hover_color',
		array(
			'label'           => __( 'Social Menu Icons Hover Color', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'type'            => 'color',
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_accessbar_enabled( $control )
					&&
					magazine_elite_is_accessbar_social_links_enabled( $control )
					&&
					magazine_elite_is_access_bar_social_icons_theme_color( $control )
				);
			},
		)
	)
);

// Social Links Display Style.
$wp_customize->add_setting(
	'access_bar_social_links_display_style',
	array(
		'default'           => $theme_options_defaults['access_bar_social_links_display_style'],
		'sanitize_callback' => 'magazine_elite_sanitize_select',
	)
);
$wp_customize->add_control(
	'access_bar_social_links_display_style',
	array(
		'label'           => __( 'Social Menu Display Style', 'magazine-elite' ),
		'section'         => 'accessbar_options',
		'type'            => 'select',
		'choices'         => magazine_elite_get_social_links_styles(),
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_accessbar_enabled( $control )
				&&
				magazine_elite_is_accessbar_social_links_enabled( $control )
			);
		},
	)
);

/*Enable Info Page*/
$wp_customize->add_setting(
	'show_access_bar_info_page',
	array(
		'default'           => $theme_options_defaults['show_access_bar_info_page'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar_info_page',
		array(
			'label'           => __( 'Enable Info Page', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

// Info Page ID.
$wp_customize->add_setting(
	'access_bar_info_page_id',
	array(
		'default'           => $theme_options_defaults['access_bar_info_page_id'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'access_bar_info_page_id',
	array(
		'label'           => __( 'Info Page ID', 'magazine-elite' ),
		'description'     => __( 'A single Post/Page ID. Ex: 11', 'magazine-elite' ),
		'section'         => 'accessbar_options',
		'type'            => 'text',
		'active_callback' => function( $control ) {
			return (
				magazine_elite_is_accessbar_enabled( $control )
				&&
				magazine_elite_is_accessbar_info_page_enabled( $control )
			);
		},
	)
);

// Info page Icon.
$wp_customize->add_setting(
	'access_bar_info_page_icon',
	array(
		'default'           => $theme_options_defaults['access_bar_info_page_icon'],
		'sanitize_callback' => 'magazine_elite_sanitize_radio',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Radio_Image_Control(
		$wp_customize,
		'access_bar_info_page_icon',
		array(
			'label'           => __( 'Info Page Icon', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'choices'         => array(
				'geo'              => array(
					'url'   => get_template_directory_uri() . '/assets/images/geo.svg',
					'label' => esc_html__( 'Geo', 'magazine-elite' ),
				),
				'geo-alt-fill'     => array(
					'url'   => get_template_directory_uri() . '/assets/images/geo-alt-fill.svg',
					'label' => esc_html__( 'Geo Alt Fill', 'magazine-elite' ),
				),
				'info-circle'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/info-circle.svg',
					'label' => esc_html__( 'Info Circle', 'magazine-elite' ),
				),
				'info-circle-fill' => array(
					'url'   => get_template_directory_uri() . '/assets/images/info-circle-fill.svg',
					'label' => esc_html__( 'Info Circle Fill', 'magazine-elite' ),
				),
				'people-fill'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/people-fill.svg',
					'label' => esc_html__( 'People Fill', 'magazine-elite' ),
				),
				'person'           => array(
					'url'   => get_template_directory_uri() . '/assets/images/person.svg',
					'label' => esc_html__( 'Person', 'magazine-elite' ),
				),
				'person-circle'    => array(
					'url'   => get_template_directory_uri() . '/assets/images/person-circle.svg',
					'label' => esc_html__( 'Person Circle', 'magazine-elite' ),
				),
			),
			'active_callback' => function( $control ) {
				return (
					magazine_elite_is_accessbar_enabled( $control )
					&&
					magazine_elite_is_accessbar_info_page_enabled( $control )
				);
			},
		)
	)
);

/*Enable Scroll to Top*/
$wp_customize->add_setting(
	'show_access_bar_scroll_top',
	array(
		'default'           => $theme_options_defaults['show_access_bar_scroll_top'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'show_access_bar_scroll_top',
		array(
			'label'           => __( 'Enable Scroll to Top', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

/*Hide on Desktop*/
$wp_customize->add_setting(
	'hide_access_bar_desktop',
	array(
		'default'           => $theme_options_defaults['hide_access_bar_desktop'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'hide_access_bar_desktop',
		array(
			'label'           => __( 'Hide Accessbar on Desktop', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

/*Hide on Tablet*/
$wp_customize->add_setting(
	'hide_access_bar_tablet',
	array(
		'default'           => $theme_options_defaults['hide_access_bar_tablet'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'hide_access_bar_tablet',
		array(
			'label'           => __( 'Hide Accessbar on Tablet', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);

/*Hide on Mobile*/
$wp_customize->add_setting(
	'hide_access_bar_mobile',
	array(
		'default'           => $theme_options_defaults['hide_access_bar_mobile'],
		'sanitize_callback' => 'magazine_elite_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Elite_Toggle_Control(
		$wp_customize,
		'hide_access_bar_mobile',
		array(
			'label'           => __( 'Hide Accessbar on Mobile', 'magazine-elite' ),
			'section'         => 'accessbar_options',
			'active_callback' => 'magazine_elite_is_accessbar_enabled',
		)
	)
);
