<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Magazine_Elite
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function magazine_elite_body_classes( $classes ) {

	global $post;

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Get Sticky menu.
	$sticky_menu = get_theme_mod( 'enable_sticky_menu', true );
	if ( $sticky_menu ) {
		$classes[] = 'has-sticky-menu';
	}

	// Get Header Style.
	$classes[] = get_theme_mod( 'header_style', 'header_style_1' );

	// Get appropriate class for the sidebar layout.
	$page_layout = magazine_elite_get_page_layout();
	if ( 'no-sidebar' == $page_layout ) {
		$classes[] = 'no-sidebar wide-container';
	} elseif ( 'no-sidebar-narrow' == $page_layout ) {
		$classes[] = 'no-sidebar narrow-container';
	} else {
		$classes[] = 'has-sidebar ' . esc_attr( $page_layout );
	}

	// Get Sticky.
	if ( is_front_page() ) {
		$enable_sidebar_border = '';
		$sticky                = get_theme_mod( 'front_page_sticky_sidebar', true );
		// Fetch from Post Meta first.
		if ( $post && is_singular() ) {
			$enable_sidebar_border = get_post_meta( $post->ID, 'magazine_elite_enable_sidebar_border', true );
		}
		if ( empty( $enable_sidebar_border ) ) {
			$enable_sidebar_border = get_theme_mod( 'front_page_enable_sidebar_border' );
		}
		if ( $enable_sidebar_border ) {
			$classes[] = 'has-sidebar-border';
		}
	} else {
		$sticky = get_theme_mod( 'sticky_sidebar', true );
		// Fetch from Post Meta on single posts or pages.
		if ( $post && is_singular() ) {
			$enable_sidebar_border = get_post_meta( $post->ID, 'magazine_elite_enable_sidebar_border', true );
			if ( empty( $enable_sidebar_border ) && is_single() ) {
				$enable_sidebar_border = get_theme_mod( 'global_enable_sidebar_border' );
			}
			if ( $enable_sidebar_border ) {
				$classes[] = 'has-sidebar-border';
			}
		}
	}
	if ( $sticky ) {
		$classes[] = 'has-sticky-sidebar';
	}

	// Get theme component style.
	$classes[] = 'component_' . esc_attr( get_theme_mod( 'theme_component_style', 'style_3' ) );

	// Get Accessbar.
	$show_access_bar = get_theme_mod( 'show_access_bar' );
	if ( $show_access_bar ) {
		$classes[] = 'has-accessbar';
		if ( get_theme_mod( 'hide_access_bar_desktop' ) ) {
			$classes[] = 'accessbar-hide-on-desktop';
		}
		if ( get_theme_mod( 'hide_access_bar_tablet', true ) ) {
			$classes[] = 'accessbar-hide-on-tablet';
		}
		if ( get_theme_mod( 'hide_access_bar_mobile', true ) ) {
			$classes[] = 'accessbar-hide-on-mobile';
		}
		if ( 'right' == get_theme_mod( 'access_bar_pos', 'right' ) ) {
			$classes[] = 'accessbar-pos-right';
		} else {
			$classes[] = 'accessbar-pos-left';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'magazine_elite_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function magazine_elite_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'magazine_elite_pingback_header' );
