<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Elite_Grid_Posts extends Magazine_Elite_Widget_Base {
	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->widget_cssclass    = 'magazine_elite_grid_posts_widget';
		$this->widget_description = __( 'Displays posts in grid style', 'magazine-elite' );
		$this->widget_id          = 'magazine_elite_grid_posts_widget';
		$this->widget_name        = __( 'Magazine Elite: Grid Posts', 'magazine-elite' );
		$this->settings           = array(
			'title'                     => array(
				'type'  => 'text',
				'label' => __( 'Title', 'magazine-elite' ),
			),
			'post_settings_heading'     => array(
				'type'  => 'heading',
				'label' => __( 'Post Settings', 'magazine-elite' ),
			),
			'post_cat'                  => array(
				'type'  => 'dropdown-taxonomies',
				'label' => __( 'Select Category', 'magazine-elite' ),
				'desc'  => __( 'Leave empty if you don\'t want the posts to be category specific', 'magazine-elite' ),
				'args'  => array(
					'taxonomy'        => 'category',
					'class'           => 'widefat',
					'hierarchical'    => true,
					'show_count'      => 1,
					'show_option_all' => __( '&mdash; Select &mdash;', 'magazine-elite' ),
				),
			),
			'no_of_posts'               => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 6,
				'label' => __( 'Number of posts to show', 'magazine-elite' ),
			),
			'orderby'                   => array(
				'type'    => 'select',
				'std'     => 'date',
				'label'   => __( 'Order By', 'magazine-elite' ),
				'options' => array(
					'date'  => __( 'Date', 'magazine-elite' ),
					'ID'    => __( 'ID', 'magazine-elite' ),
					'title' => __( 'Title', 'magazine-elite' ),
					'rand'  => __( 'Random', 'magazine-elite' ),
				),
			),
			'order'                     => array(
				'type'    => 'select',
				'std'     => 'desc',
				'label'   => __( 'Order', 'magazine-elite' ),
				'options' => array(
					'asc'  => __( 'ASC', 'magazine-elite' ),
					'desc' => __( 'DESC', 'magazine-elite' ),
				),
			),
			'meta_settings_heading'     => array(
				'type'  => 'heading',
				'label' => __( 'Post Meta Settings', 'magazine-elite' ),
			),
			'post_meta'                 => array(
				'type'    => 'multi-checkbox',
				'label'   => __( 'Post Meta', 'magazine-elite' ),
				'options' => array(
					'author'    => __( 'Author', 'magazine-elite' ),
					'read_time' => __( 'Post Read Time', 'magazine-elite' ),
					'date'      => __( 'Date', 'magazine-elite' ),
					'comment'   => __( 'Comment', 'magazine-elite' ),
				),
				'std'     => array( 'date' ),
			),
			'date_format'               => array(
				'type'    => 'select',
				'label'   => __( 'Date Format', 'magazine-elite' ),
				'desc'    => __( 'Make sure to select Date from above for this to work.', 'magazine-elite' ),
				'options' => array(
					'format_1' => __( 'Times Ago', 'magazine-elite' ),
					'format_2' => __( 'Default Format', 'magazine-elite' ),
				),
				'std'     => 'format_2',
			),
			'author_image'              => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Author Image', 'magazine-elite' ),
				'desc'  => __( 'Make sure to select Author from above for this to work.', 'magazine-elite' ),
				'std'   => false,
			),
			'excerpt_settings_heading'  => array(
				'type'  => 'heading',
				'label' => __( 'Excerpt Settings', 'magazine-elite' ),
			),
			'show_excerpt'              => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Excerpt', 'magazine-elite' ),
				'std'   => true,
			),
			'content_length'            => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 0,
				'max'   => '',
				'std'   => 25,
				'label' => __( 'Excerpt Length', 'magazine-elite' ),
			),
			'category_settings_heading' => array(
				'type'  => 'heading',
				'label' => __( 'Category Settings', 'magazine-elite' ),
			),
			'show_category'             => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Category', 'magazine-elite' ),
				'std'   => false,
			),
			'category_color'            => array(
				'type'    => 'select',
				'label'   => __( 'Category Color', 'magazine-elite' ),
				'options' => magazine_elite_get_category_color_display(),
				'std'     => 'none',
			),
			'category_style'            => array(
				'type'    => 'select',
				'label'   => __( 'Category Style', 'magazine-elite' ),
				'options' => magazine_elite_get_category_styles(),
				'std'     => 'style_1',
			),
			'no_of_category'            => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 0,
				'max'   => '',
				'std'   => 1,
				'label' => __( 'Number of Category to Display', 'magazine-elite' ),
			),
			'widget_settings_heading'   => array(
				'type'  => 'heading',
				'label' => __( 'Widget Settings', 'magazine-elite' ),
			),
			'style'                     => array(
				'type'    => 'select',
				'label'   => __( 'Style', 'magazine-elite' ),
				'options' => array(
					'style_1' => __( 'Content Pull Over Image', 'magazine-elite' ),
					'style_2' => __( 'Content Below Image', 'magazine-elite' ),
				),
				'std'     => 'style_1',
			),
			'no_of_column'              => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 2,
				'max'   => 5,
				'std'   => 2,
				'label' => __( 'Number of Column', 'magazine-elite' ),
			),
			'enable_post_format_icon'   => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Post Format Icon', 'magazine-elite' ),
				'std'   => false,
			),
			'title_limit'               => array(
				'type'    => 'select',
				'label'   => __( 'Post Title Limit', 'magazine-elite' ),
				'options' => magazine_elite_get_title_limit_choices(),
				'std'     => '',
			),
		);

		parent::__construct();
	}

	/**
	 * Query the posts and return them.
	 *
	 * @param  array $args
	 * @param  array $instance
	 * @return WP_Query
	 */
	public function get_posts( $args, $instance ) {
		$number  = ! empty( $instance['no_of_posts'] ) ? absint( $instance['no_of_posts'] ) : $this->settings['no_of_posts']['std'];
		$orderby = ! empty( $instance['orderby'] ) ? sanitize_text_field( $instance['orderby'] ) : $this->settings['orderby']['std'];
		$order   = ! empty( $instance['order'] ) ? sanitize_text_field( $instance['order'] ) : $this->settings['order']['std'];

		$query_args = array(
			'posts_per_page'      => $number,
			'post_status'         => 'publish',
			'no_found_rows'       => 1,
			'orderby'             => $orderby,
			'order'               => $order,
			'ignore_sticky_posts' => 1,
		);

		if ( ! empty( $instance['post_cat'] ) && -1 != $instance['post_cat'] && 0 != $instance['post_cat'] ) {
			$query_args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'term_id',
				'terms'    => $instance['post_cat'],
			);
		}

		return new WP_Query( apply_filters( 'magazine_elite_grid_posts_query_args', $query_args ) );
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {

		ob_start();

		if ( ( $posts = $this->get_posts( $args, $instance ) ) && $posts->have_posts() ) {
			$this->widget_start( $args, $instance );

			do_action( 'magazine_elite_before_grid_posts' );

			$style                   = isset( $instance['style'] ) ? $instance['style'] : $this->settings['style']['std'];
			$column                  = isset( $instance['no_of_column'] ) ? $instance['no_of_column'] : $this->settings['no_of_column']['std'];
			$title_limit             = isset( $instance['title_limit'] ) ? $instance['title_limit'] : $this->settings['title_limit']['std'];
			$enable_post_format_icon = isset( $instance['enable_post_format_icon'] ) ? $instance['enable_post_format_icon'] : $this->settings['enable_post_format_icon']['std'];
			$show_excerpt            = isset( $instance['show_excerpt'] ) ? $instance['show_excerpt'] : $this->settings['show_excerpt']['std'];
			$show_category           = isset( $instance['show_category'] ) ? $instance['show_category'] : $this->settings['show_category']['std'];
			if ( $show_category ) {
				$cat_style = isset( $instance['category_style'] ) ? $instance['category_style'] : $this->settings['category_style']['std'];
				$color     = isset( $instance['category_color'] ) ? $instance['category_color'] : $this->settings['category_color']['std'];
				$limit     = isset( $instance['no_of_category'] ) ? $instance['no_of_category'] : $this->settings['no_of_category']['std'];
			}
			$enabled_post_meta             = isset( $instance['post_meta'] ) ? $instance['post_meta'] : $this->settings['post_meta']['std'];
			$meta_settings['date_format']  = isset( $instance['date_format'] ) ? $instance['date_format'] : $this->settings['date_format']['std'];
			$meta_settings['author_image'] = isset( $instance['author_image'] ) ? $instance['author_image'] : $this->settings['author_image']['std'];

			$col_class = 'row row-cols-1 row-cols-sm-2 row-cols-md-2 g-4';

			if ( 2 == $column ) {
				$col_class .= ' magazine-elite-grid-2';
			} elseif ( 3 == $column ) {
				$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
			} elseif ( 4 == $column ) {
				$col_class .= ' row-cols-xl-4 magazine-elite-grid-4';
			} elseif ( 5 == $column ) {
				$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-elite-grid-5';
			} else {
				$col_class .= ' row-cols-lg-2 magazine-elite-grid-2';
			}

			$widget_wrapper_class         = $style;
			$article_wrapper_class        = ( 'style_2' == $style ) ? ' magazine-elite-card-box' : '';
			$article_detail_wrapper_class = ( 'style_1' == $style ) ? ' magazine-elite-card-box' : '';
			?>

			<div class="magazine-elite-grid-posts-widget <?php echo esc_attr( $widget_wrapper_class ); ?>">
				<div class="<?php echo esc_attr( $col_class ); ?>">
					<?php
					while ( $posts->have_posts() ) :
						$posts->the_post();
						?>
							<div class="col">
								<div class="article-block-wrapper img-animate-zoom<?php echo esc_attr( $article_wrapper_class ); ?>">
									<?php
									if ( has_post_thumbnail() ) {
										?>
										<div class="article-image">
											<a href="<?php the_permalink(); ?>">
												<?php
												if ( $enable_post_format_icon ) {
													magazine_elite_post_format_icon( 'center' );
												}
												?>
												<?php
												the_post_thumbnail(
													'magazine-elite-large-img',
													array(
														'alt' => the_title_attribute(
															array(
																'echo' => false,
															)
														),
													)
												);
												?>
											</a>
										</div>
										<?php
									}
									?>
									<div class="article-details<?php echo esc_attr( $article_detail_wrapper_class ); ?>">
										<?php
										if ( $show_category ) {
											echo '<div class="article-cat-info">';
											magazine_elite_post_categories( $cat_style, $color, $limit );
											echo '</div>';
										}
										?>
										<h3 class="article-title">
											<a href="<?php the_permalink(); ?>" class="text-decoration-none color-accent-hover magazine-elite-limit-lines <?php echo esc_attr( $title_limit ); ?>">
												<?php the_title(); ?>
											</a>
										</h3>
										<?php
										magazine_elite_post_meta_info( $enabled_post_meta, $meta_settings );
										if ( $show_excerpt ) {
											?>
											<div class="article-excerpt">
												<p class="no-margin">
													<?php echo wp_trim_words( get_the_excerpt(), $instance['content_length'], '' ); ?>
												</p>
											</div>
										<?php } ?>
									</div>
								</div>
							</div>
						<?php
					endwhile;
					wp_reset_postdata();
					?>
				</div>
			</div>
			<?php

			do_action( 'magazine_elite_after_grid_posts' );

			$this->widget_end( $args );
		}

		echo ob_get_clean();
	}

}
