<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Elite_Recent_Posts extends Magazine_Elite_Widget_Base {

	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->widget_cssclass    = 'widget_magazine_elite_recent_posts';
		$this->widget_description = __( 'Displays recent posts with an image', 'magazine-elite' );
		$this->widget_id          = 'magazine_elite_recent_posts';
		$this->widget_name        = __( 'Magazine Elite: Recent Posts', 'magazine-elite' );
		$this->settings           = array(
			'title'                   => array(
				'type'  => 'text',
				'label' => __( 'Title', 'magazine-elite' ),
			),
			'post_settings_heading'   => array(
				'type'  => 'heading',
				'label' => __( 'Post Settings', 'magazine-elite' ),
			),
			'category'                => array(
				'type'  => 'dropdown-taxonomies',
				'label' => __( 'Select Category', 'magazine-elite' ),
				'desc'  => __( 'Leave empty if you don\'t want the posts to be category specific', 'magazine-elite' ),
				'args'  => array(
					'taxonomy'        => 'category',
					'class'           => 'widefat',
					'hierarchical'    => true,
					'show_count'      => 1,
					'show_option_all' => __( '&mdash; Select &mdash;', 'magazine-elite' ),
				),
			),
			'number'                  => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 3,
				'label' => __( 'Number of posts to show', 'magazine-elite' ),
			),
			'orderby'                 => array(
				'type'    => 'select',
				'std'     => 'date',
				'label'   => __( 'Order by', 'magazine-elite' ),
				'options' => array(
					'date'  => __( 'Date', 'magazine-elite' ),
					'ID'    => __( 'ID', 'magazine-elite' ),
					'title' => __( 'Title', 'magazine-elite' ),
					'rand'  => __( 'Random', 'magazine-elite' ),
				),
			),
			'order'                   => array(
				'type'    => 'select',
				'std'     => 'desc',
				'label'   => __( 'Order', 'magazine-elite' ),
				'options' => array(
					'asc'  => __( 'ASC', 'magazine-elite' ),
					'desc' => __( 'DESC', 'magazine-elite' ),
				),
			),
			'meta_settings_heading'   => array(
				'type'  => 'heading',
				'label' => __( 'Post Meta Settings', 'magazine-elite' ),
			),
			'post_meta'               => array(
				'type'    => 'multi-checkbox',
				'label'   => __( 'Post Meta', 'magazine-elite' ),
				'options' => array(
					'author'    => __( 'Author', 'magazine-elite' ),
					'read_time' => __( 'Post Read Time', 'magazine-elite' ),
					'date'      => __( 'Date', 'magazine-elite' ),
					'comment'   => __( 'Comment', 'magazine-elite' ),
				),
				'std'     => array( 'date' ),
			),
			'date_format'             => array(
				'type'    => 'select',
				'label'   => __( 'Date Format', 'magazine-elite' ),
				'desc'    => __( 'Make sure to select Date from above for this to work.', 'magazine-elite' ),
				'options' => array(
					'format_1' => __( 'Times Ago', 'magazine-elite' ),
					'format_2' => __( 'Default Format', 'magazine-elite' ),
				),
				'std'     => 'format_1',
			),
			'author_image'            => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Author Image', 'magazine-elite' ),
				'desc'  => __( 'Make sure to select Author from above for this to work.', 'magazine-elite' ),
				'std'   => false,
			),
			'widget_settings_heading' => array(
				'type'  => 'heading',
				'label' => __( 'Widget Settings', 'magazine-elite' ),
			),
			'style'                   => array(
				'type'    => 'select',
				'label'   => __( 'Style', 'magazine-elite' ),
				'options' => array(
					'style_1' => __( 'Default', 'magazine-elite' ),
					'style_2' => __( 'Circled Image', 'magazine-elite' ),
					'style_3' => __( 'With Background', 'magazine-elite' ),
				),
				'std'     => 'style_1',
			),
			'enable_post_format_icon' => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Post Format Icon', 'magazine-elite' ),
				'std'   => false,
			),
			'invert_list_post'        => array(
				'type'  => 'checkbox',
				'label' => __( 'Invert List Post', 'magazine-elite' ),
				'std'   => false,
			),
			'title_limit'             => array(
				'type'    => 'select',
				'label'   => __( 'Post Title Limit', 'magazine-elite' ),
				'options' => magazine_elite_get_title_limit_choices(),
				'std'     => '',
			),
			'enable_item_separator'   => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Item Separator', 'magazine-elite' ),
				'std'   => false,
			),
			'hide_list_image'         => array(
				'type'  => 'checkbox',
				'label' => __( 'Hide List Post Image', 'magazine-elite' ),
				'std'   => false,
			),
		);

		parent::__construct();
	}

	/**
	 * Query the posts and return them.
	 *
	 * @param  array $args
	 * @param  array $instance
	 * @return WP_Query
	 */
	public function get_posts( $args, $instance ) {
		$number  = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
		$orderby = ! empty( $instance['orderby'] ) ? sanitize_text_field( $instance['orderby'] ) : $this->settings['orderby']['std'];
		$order   = ! empty( $instance['order'] ) ? sanitize_text_field( $instance['order'] ) : $this->settings['order']['std'];

		$query_args = array(
			'posts_per_page'      => $number,
			'post_status'         => 'publish',
			'no_found_rows'       => 1,
			'orderby'             => $orderby,
			'order'               => $order,
			'ignore_sticky_posts' => 1,
		);

		if ( ! empty( $instance['category'] ) && -1 != $instance['category'] && 0 != $instance['category'] ) {
			$query_args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'term_id',
				'terms'    => $instance['category'],
			);
		}

		return new WP_Query( apply_filters( 'magazine_elite_recent_posts_query_args', $query_args ) );
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {

		ob_start();

		if ( ( $posts = $this->get_posts( $args, $instance ) ) && $posts->have_posts() ) {
			$this->widget_start( $args, $instance );

			do_action( 'magazine_elite_before_recent_posts' );

			$class                         = '';
			$style                         = $instance['style'];
			$widget_class                  = $style;
			$enable_post_format_icon       = isset( $instance['enable_post_format_icon'] ) ? $instance['enable_post_format_icon'] : $this->settings['enable_post_format_icon']['std'];
			$title_limit                   = isset( $instance['title_limit'] ) ? $instance['title_limit'] : $this->settings['title_limit']['std'];
			$enabled_post_meta             = isset( $instance['post_meta'] ) ? $instance['post_meta'] : $this->settings['post_meta']['std'];
			$meta_settings['date_format']  = isset( $instance['date_format'] ) ? $instance['date_format'] : $this->settings['date_format']['std'];
			$meta_settings['author_image'] = isset( $instance['author_image'] ) ? $instance['author_image'] : $this->settings['author_image']['std'];

			// Inverted Item.
			$invert_list_post = isset( $instance['invert_list_post'] ) ? $instance['invert_list_post'] : $this->settings['invert_list_post']['std'];
			if ( $invert_list_post ) {
				$widget_class .= ' saga-inverted-item';
			}
			// Item Separator.
			$item_separator = isset( $instance['enable_item_separator'] ) ? $instance['enable_item_separator'] : $this->settings['enable_item_separator']['std'];
			if ( $item_separator ) {
				$widget_class .= ' saga-item-sep';
			}
			// Hide List Image.
			$show_image      = true;
			$hide_list_image = isset( $instance['hide_list_image'] ) ? $instance['hide_list_image'] : $this->settings['hide_list_image']['std'];
			if ( $hide_list_image ) {
				$widget_class .= ' saga-hidden-post-image';
				$show_image    = false;
			}
			if ( 'style_1' === $style ) {
				$class = ' img-animate-zoom';
			}
			if ( 'style_3' === $style ) {
				$class = ' magazine-elite-card-box img-animate-zoom';
			}

			?>

			<div class="magazine-elite-recent-posts-widget <?php echo esc_attr( $widget_class ); ?>">
				<div class="magazine-elite-list-posts">
					<?php
					while ( $posts->have_posts() ) :
						$posts->the_post();
						?>
							<div class="article-block-wrapper<?php echo esc_attr( $class ); ?>">
								<?php
								if ( $show_image && has_post_thumbnail() ) {
									?>
									<div class="article-image">
										<a href="<?php the_permalink(); ?>">
											<?php
											if ( $enable_post_format_icon ) {
												magazine_elite_post_format_icon( 'center' );
											}
											?>
											<?php
											the_post_thumbnail(
												'thumbnail',
												array(
													'alt' => the_title_attribute(
														array(
															'echo' => false,
														)
													),
												)
											);
											?>
										</a>
									</div>
									<?php
								}
								?>
								<div class="article-details">
									<h3 class="entry-title no-margin">
										<a href="<?php the_permalink(); ?>" class="text-decoration-none color-accent-hover magazine-elite-limit-lines <?php echo esc_attr( $title_limit ); ?>">
											<?php the_title(); ?>
										</a>
									</h3>
									<?php magazine_elite_post_meta_info( $enabled_post_meta, $meta_settings ); ?>
								</div>
							</div>
						<?php
					endwhile;
					wp_reset_postdata();
					?>
				</div>
			</div>
			<?php

			do_action( 'magazine_elite_after_recent_posts_with_image' );

			$this->widget_end( $args );
		}

		echo ob_get_clean();
	}

}
