<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Elite_Social_Menu extends Magazine_Elite_Widget_Base {

	/**
	 * Constructor.
	 */
	public function __construct() {
		 $this->widget_cssclass   = 'widget_magazine_elite_social_menu';
		$this->widget_description = __( 'Displays social menu if you have set it.', 'magazine-elite' );
		$this->widget_id          = 'magazine_elite_social_menu_widget';
		$this->widget_name        = __( 'Magazine Elite: Social Menu', 'magazine-elite' );
		$this->settings           = array(
			'title' => array(
				'type'  => 'text',
				'label' => __( 'Title', 'magazine-elite' ),
			),
			'color' => array(
				'type'    => 'select',
				'label'   => __( 'Social Links Color', 'magazine-elite' ),
				'options' => array(
					'theme_color' => __( 'Use Theme Color', 'magazine-elite' ),
					'brand_color' => __( 'Use Brand Color', 'magazine-elite' ),
				),
				'std'     => 'theme_color',
			),
			'style' => array(
				'type'    => 'select',
				'label'   => __( 'Style', 'magazine-elite' ),
				'options' => magazine_elite_get_social_links_styles(),
				'std'     => 'style_1',
			),
			'show_label' => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Label', 'magazine-elite' ),
				'std'   => false,
			),
			'column'     => array(
				'type'    => 'select',
				'label'   => __( 'Column', 'magazine-elite' ),
				'desc'    => __( 'Will only work when label is enabled from above and there is enough space to display the columns.', 'magazine-elite' ),
				'options' => array(
					'one'   => __( 'One', 'magazine-elite' ),
					'two'   => __( 'Two', 'magazine-elite' ),
					'three' => __( 'Three', 'magazine-elite' ),
				),
				'std'     => 'two',
			),
			'align' => array(
				'type'    => 'select',
				'label'   => __( 'Alignment', 'magazine-elite' ),
				'options' => array(
					'left'   => __( 'Left', 'magazine-elite' ),
					'center' => __( 'Center', 'magazine-elite' ),
					'right'  => __( 'Right', 'magazine-elite' ),
				),
				'std'     => 'left',
			),
		);

		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		ob_start();

		$this->widget_start( $args, $instance );

		do_action( 'magazine_elite_before_social_menu' );

		$wrapper_class = isset( $instance['align'] ) ? $instance['align'] : $this->settings['align']['std'];

		?>
		<div class="magazine-elite-social-menu-widget menu-align-<?php echo esc_attr( $wrapper_class ); ?>">
			<?php

			if ( has_nav_menu( 'social-menu' ) ) {

				$social_link_class  = ' reset-list-style magazine-elite-social-icons ';
				$social_link_style  = isset( $instance['style'] ) ? $instance['style'] : $this->settings['style']['std'];
				$social_link_style .= magazine_elite_get_social_icons_class( $social_link_style );
				$social_link_color  = isset( $instance['color'] ) ? $instance['color'] : $this->settings['color']['std'];

				$social_link_class .= $social_link_style . ' ' . $social_link_color;

				$label_class = 'screen-reader-text';
				$show_label  = isset( $instance['show_label'] ) ? $instance['show_label'] : $this->settings['show_label']['std'];
				if ( $show_label ) {
					$label_class        = 'me-social-menu-label';
					$social_link_class .= ' has-social-menu-label';
					$column             = isset( $instance['column'] ) ? $instance['column'] : $this->settings['column']['std'];
					$social_link_class .= ' me-flex-col-' . $column;
				}

				wp_nav_menu(
					array(
						'theme_location'  => 'social-menu',
						'container_class' => 'social-navigation',
						'fallback_cb'     => false,
						'depth'           => 1,
						'menu_class'      => $social_link_class,
						'link_before'     => '<span class="' . $label_class . '">',
						'link_after'      => '</span>',
					)
				);
			} else {
				esc_html_e( 'Social menu is not set. You need to create menu and assign it to Social Menu on Menu Settings.', 'magazine-elite' );
			}
			?>
		</div>
		<?php

		do_action( 'magazine_elite_after_social_menu' );

		$this->widget_end( $args );

		echo ob_get_clean();
	}
}
