<?php
/**
 * Template part for displaying post archives
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Magazine_Elite
 */

$class             = 'magazine-elite-card-box';
$enabled_post_meta = get_theme_mod( 'archive_post_meta', array( 'date', 'category' ) );
set_query_var( 'enabled_post_meta', $enabled_post_meta );

$cats_enabled = $tags_enabled = false;

$cat_position  = get_theme_mod( 'archive_category_position', 'after_excerpt' );
$meta_settings = array(
	'date_format'  => get_theme_mod( 'archive_date_format', 'format_2' ),
	'author_image' => get_theme_mod( 'enable_archive_author_image' ),
);

$show_archive_excerpt = get_theme_mod( 'show_archive_excerpt', true );
$show_read_more       = get_theme_mod( 'show_archive_read_more' );
if ( $show_read_more ) {
	$read_more_text  = get_theme_mod( 'excerpt_read_more_text' );
	if ( ! $read_more_text ) {
		$read_more_text = __( 'Read More', 'magazine-elite' );
	}
	$read_more_icon  = get_theme_mod( 'excerpt_read_more_icon' );
	$read_more_style = get_theme_mod( 'archive_read_more_style', 'style_1' );
}

// Build category.
if ( in_array( 'category', $enabled_post_meta ) ) {
	$cats_enabled = true;
	$cat_style    = get_theme_mod( 'archive_category_style', 'style_1' );
	$cat_color    = get_theme_mod( 'archive_category_color_display', 'none' );
	$cat_limit    = get_theme_mod( 'archive_category_limit', 3 );
	$cat_label    = get_theme_mod( 'enable_archive_cat_label', true );
}

// Build tags.
if ( in_array( 'tags', $enabled_post_meta ) ) {
	$tags_enabled = true;
	$tag_style    = get_theme_mod( 'archive_tag_style', 'style_1' );
	$tag_limit    = get_theme_mod( 'archive_tag_limit', 3 );
	$tag_label    = get_theme_mod( 'enable_archive_tag_label', true );
}

$archive_title_limit   = get_theme_mod( 'archive_posts_title_limit' );

// Use custom query if available.
global $wp_query;
$custom_archive_query = isset( $archive_query ) ? $archive_query : $wp_query;
while ( $custom_archive_query->have_posts() ) :
	$custom_archive_query->the_post();

	$post_format = get_post_format();
	if ( ! $post_format ) :
		$post_format = 'standard';
	endif;
	?>

	<article id="post-<?php the_ID(); ?>" <?php post_class( $class ); ?>>

		<div class="article-block-wrapper">

			<?php if ( ! in_array( $post_format, array( 'aside', 'status' ) ) ) : ?>

				<header class="entry-header">
					<?php
					if ( 'post' === get_post_type() ) :
						if ( $cats_enabled && 'before_title' == $cat_position ) :
							magazine_elite_post_categories( $cat_style, $cat_color, $cat_limit, $cat_label );
						endif;
					endif;
					?>
					<h2 class="entry-title">
						<a href="<?php the_permalink(); ?>" class="magazine-elite-limit-lines <?php echo esc_attr( $archive_title_limit ); ?>"><?php the_title(); ?></a>
					</h2>
					<?php if ( 'post' === get_post_type() ) : ?>
						<div class="entry-meta">
							<?php magazine_elite_post_meta_info( $enabled_post_meta, $meta_settings ); ?>
						</div>
					<?php endif; ?>
				</header>

				<?php if ( ! in_array( $post_format, array( 'gallery', 'audio', 'video' ) ) ) : ?>
					<?php if ( has_post_thumbnail() && ! post_password_required() ) : ?>
						<div class="entry-image img-animate-zoom">
							<a href="<?php the_permalink(); ?>">
								<figure class="featured-media">
									<?php
									the_post_thumbnail( 'magazine-elite-cover-image' );
									$caption = get_the_post_thumbnail_caption();
									if ( $caption ) :
										?>
										<figcaption class="wp-caption-text"><?php echo wp_kses_post( $caption ); ?></figcaption>
									<?php endif; ?>
								</figure><!-- .featured-media -->
							</a>
						</div><!-- .entry-image -->
					<?php endif; ?>
				<?php endif; ?>

			<?php endif; ?>

			<div class="entry-summary">
				<?php get_template_part( 'template-parts/archive/post-formats/' . $post_format ); ?>
				<?php
				if ( $show_read_more ) :
					if ( ! in_array( $post_format, array( 'aside', 'status', 'link', 'quote' ) ) ) :
						?>
						<a href="<?php the_permalink(); ?>" class="magazine-elite-read-more text-decoration-none read-more-link <?php echo esc_attr( $read_more_style ); ?>">
							<?php
							echo esc_html( $read_more_text );
							if ( $read_more_icon ) :
								?>
								<span><?php echo magazine_elite_the_theme_svg( $read_more_icon ); ?></span>
								<?php
							endif;
							?>
						</a>
						<?php
					endif;
				endif;
				?>
			</div>

			<?php
			if ( 'post' === get_post_type() ) :
				if ( ! in_array( $post_format, array( 'aside', 'status' ) ) ) :
					if ( $cats_enabled && 'after_excerpt' == $cat_position ) :
						magazine_elite_post_categories( $cat_style, $cat_color, $cat_limit, $cat_label );
					endif;
					if ( $tags_enabled ) :
						magazine_elite_post_tags( $tag_style, $tag_limit, $tag_label );
					endif;
				endif;
			endif;
			magazine_elite_post_edit_link();
			?>
			
		</div>

	</article><!-- #post-<?php the_ID(); ?> -->

	<?php
endwhile;
wp_reset_postdata();
