<?php

// Topbar Date.
if ( ! function_exists( 'magazine_elite_topbar_date' ) ) :
	function magazine_elite_topbar_date() {
		if ( get_theme_mod( 'enable_todays_date' ) ) :
			$date_format = get_theme_mod( 'todays_date_format', 'l, F j Y' );
			?>
			<div class="magazine-elite-components-date">
				<span><?php echo esc_html( date_i18n( $date_format, current_time( 'timestamp' ) ) ); ?></span>
			</div>
			<?php
		endif;
	}
endif;
add_action( 'magazine_elite_topbar_first_col_items', 'magazine_elite_topbar_date', 10 );

// Topbar Nav.
if ( ! function_exists( 'magazine_elite_topbar_nav' ) ) :
	function magazine_elite_topbar_nav() {
		if ( get_theme_mod( 'show_top_bar_nav', true ) ) :
			wp_nav_menu(
				array(
					'theme_location'  => 'top-menu',
					'container_class' => 'magazine-elite-top-nav',
					'fallback_cb'     => false,
					'depth'           => 2,
					'menu_class'      => 'magazine-elite-top-menu reset-list-style',
				)
			);
		endif;
	}
endif;
add_action( 'magazine_elite_topbar_first_col_items', 'magazine_elite_topbar_nav', 20 );

// Topbar Social icons.
if ( ! function_exists( 'magazine_elite_topbar_social' ) ) :
	function magazine_elite_topbar_social() {
		if ( get_theme_mod( 'show_top_bar_social_nav' ) ) :

			$menu_class         = ' reset-list-style magazine-elite-social-icons ';
			$social_link_style  = get_theme_mod( 'header_social_links_display_style', 'style_1' );
			$social_link_style .= magazine_elite_get_social_icons_class( $social_link_style );
			$social_link_color  = get_theme_mod( 'header_social_links_color_as', 'theme_color' );
			$menu_class        .= $social_link_style . ' ' . $social_link_color;

			wp_nav_menu(
				array(
					'theme_location'  => 'social-menu',
					'container_class' => 'magazine-elite-social-nav',
					'fallback_cb'     => false,
					'depth'           => 1,
					'menu_class'      => $menu_class,
					'link_before'     => '<span class="screen-reader-text">',
					'link_after'      => '</span>',
				)
			);
		endif;
	}
endif;
add_action( 'magazine_elite_topbar_last_col_items', 'magazine_elite_topbar_social', 10 );

// Topbar WooCommerce Icons.
if ( ! function_exists( 'magazine_elite_topbar_woo_icons' ) ) :
	function magazine_elite_topbar_woo_icons() {

		if ( magazine_elite_is_wc_active() ) :

			if ( get_theme_mod( 'enable_woo_my_account_top_bar' ) ) :
				$my_account_page = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
				if ( is_user_logged_in() ) :
					?>
					<a href="<?php echo esc_url( $my_account_page ); ?>" class="site-header-account" title="<?php esc_attr_e( 'My Account', 'magazine-elite' ); ?>">
					<?php magazine_elite_the_theme_svg( 'login' ); ?>
					</a>
				<?php else : ?>
					<a href="<?php echo esc_url( $my_account_page ); ?>" class="site-header-account" title="<?php esc_attr_e( 'Login / Register', 'magazine-elite' ); ?>">
					<?php magazine_elite_the_theme_svg( 'login' ); ?>
					</a>
					<?php
				endif;
			endif;

			if ( get_theme_mod( 'enable_woo_mini_cart_top_bar' ) ) :
				magazine_elite_woocommerce_header_cart();
			endif;

		endif;

	}
endif;
add_action( 'magazine_elite_topbar_last_col_items', 'magazine_elite_topbar_woo_icons', 20 );

// Topbar Search.
if ( ! function_exists( 'magazine_elite_topbar_search' ) ) :
	function magazine_elite_topbar_search() {
		if ( get_theme_mod( 'enable_search_on_top_bar', true ) ) :
			$btn_class = '';
			if ( 'style_2' == get_theme_mod( 'header_search_btn_style', 'style_2' ) ) {
				$btn_class = 'toggle ';
			}
			?>
			<div class="magazine-elite-search-toggle">
				<button class="magazine-elite-search-canvas-btn magazine-elite-search search-icon toggle-canvas-modal <?php echo esc_attr( $btn_class ); ?>" aria-expanded="false" data-modal=".magazine-elite-search-block" data-body-class="showing-search-modal" data-focus=".magazine-elite-search-block .search-field">
					<span class="search-label"><?php esc_html_e( 'Search', 'magazine-elite' ); ?></span>
					<?php magazine_elite_the_theme_svg( 'search' ); ?>
				</button>
			</div>
			<?php
		endif;
	}
endif;
add_action( 'magazine_elite_topbar_last_col_items', 'magazine_elite_topbar_search', 30 );

// Primary Menu Bar Offcanvas Icon.
if ( ! function_exists( 'magazine_elite_primary_bar_offcanvas' ) ) :
	function magazine_elite_primary_bar_offcanvas() {
		$class = '';
		if ( get_theme_mod( 'offcanvas_hide_desktop', true ) ) {
			$class .= ' hide-on-desktop';
		}
		?>
		<div class="magazine-elite-offcanvas-toggle<?php echo esc_attr( $class ); ?>">
			<button class="magazine-elite-off-canvas-btn toggle toggle-off-canvas toggle-canvas-modal" data-modal=".magazine-elite-canvas-block" data-body-class="showing-offcanvas-modal" data-focus=".magazine-elite-off-canvas-close" aria-expanded="false">
				<span class="off-canvas-bars">
					<span class="bar-top"></span>
					<span class="bar-mid"></span>
					<span class="bar-low"></span>
				</span>
				<span class="toggle-text screen-reader-text">
					<?php esc_html_e( 'Off Canvas', 'magazine-elite' ); ?>
				</span>
			</button>
		</div>
		<?php
	}
endif;
add_action( 'magazine_elite_primary_nav_items', 'magazine_elite_primary_bar_offcanvas', 10 );

// Primary Menu Bar Menu.
if ( ! function_exists( 'magazine_elite_primary_bar_menu' ) ) :
	function magazine_elite_primary_bar_menu() {
		if ( get_theme_mod( 'center_align_primary_nav', true ) ) {
			$class = ' center-aligned-menu';
		} else {
			$class = ' left-aligned-menu';
		}
		?>
		<div id="site-navigation" class="main-navigation magazine-elite-primary-nav<?php echo esc_attr( $class ); ?>">
			
			<?php
			if ( has_nav_menu( 'primary-menu' ) ) :
				$delimiter = get_theme_mod( 'primary_menu_delimiter', 'none' );
				if ( 'none' != $delimiter ) {
					$delimiter = ' delimiter-' . $delimiter;
				} else {
					$delimiter = '';
				}
				?>
				<nav class="primary-menu-wrapper" aria-label="<?php echo esc_attr_x( 'Primary', 'menu', 'magazine-elite' ); ?>">
					<ul class="primary-menu reset-list-style<?php echo esc_attr( $delimiter ); ?>">
					<?php
					wp_nav_menu(
						array(
							'container'      => '',
							'items_wrap'     => '%3$s',
							'theme_location' => 'primary-menu',
						)
					);
					?>
					</ul>
				</nav><!-- .primary-menu-wrapper -->
			<?php endif; ?>
		</div>
		<?php
	}
endif;
add_action( 'magazine_elite_primary_nav_items', 'magazine_elite_primary_bar_menu', 20 );

// Primary Menu Bar Site Branding.
if ( ! function_exists( 'magazine_elite_primary_bar_branding' ) ) :
	function magazine_elite_primary_bar_branding() {
		?>
		<div class="site-branding">
			<?php
			if ( get_theme_mod( 'enable_different_logo_menu_bar' ) ) {
				$logo_menu_bar = get_theme_mod( 'logo_menu_bar' );
				if ( $logo_menu_bar ) {
					$logo_menu_bar = "<img src='" . esc_url( $logo_menu_bar ) . "' decoding='async'>";
					?>
					<div class="site-logo">
						<?php
						if ( is_front_page() && ! is_paged() ) {
							// If on the home page, don't link the logo to home.
							$html = sprintf(
								'<span class="custom-logo-link">%1$s</span>',
								$logo_menu_bar
							);
						} else {
							$aria_current = is_front_page() && ! is_paged() ? ' aria-current="page"' : '';

							$html = sprintf(
								'<a href="%1$s" class="custom-logo-link" rel="home"%2$s>%3$s</a>',
								esc_url( home_url( '/' ) ),
								$aria_current,
								$logo_menu_bar
							);
						}
						echo $html;
						?>
					</div>
					<?php
				}
			} else {
				if ( has_custom_logo() ) {
					?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
					<?php
				} else {
					$blog_info    = get_bloginfo( 'name' );
					$hide_title   = get_theme_mod( 'hide_title' );
					$header_class = $hide_title ? 'screen-reader-text' : 'site-title';
					if ( $blog_info ) {
						?>
						<h1 class="<?php echo esc_attr( $header_class ); ?>"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( $blog_info ); ?></a></h1>
						<?php
					}
				}
			}
			?>
		</div>
		<?php
	}
endif;
add_action( 'magazine_elite_primary_nav_items', 'magazine_elite_primary_bar_branding', 30 );

// Primary Menu Bar Social icons.
if ( ! function_exists( 'magazine_elite_primary_bar_social' ) ) :
	function magazine_elite_primary_bar_social() {
		if ( get_theme_mod( 'show_menu_bar_social_nav' ) ) :

			$menu_class         = ' reset-list-style magazine-elite-social-icons ';
			$social_link_style  = get_theme_mod( 'header_social_links_display_style', 'style_1' );
			$social_link_style .= magazine_elite_get_social_icons_class( $social_link_style );
			$social_link_color  = get_theme_mod( 'header_social_links_color_as', 'theme_color' );
			$menu_class        .= $social_link_style . ' ' . $social_link_color;

			wp_nav_menu(
				array(
					'theme_location'  => 'social-menu',
					'container_class' => 'magazine-elite-social-nav',
					'fallback_cb'     => false,
					'depth'           => 1,
					'menu_class'      => $menu_class,
					'link_before'     => '<span class="screen-reader-text">',
					'link_after'      => '</span>',
				)
			);
		endif;
	}
endif;
add_action( 'magazine_elite_secondary_nav_items', 'magazine_elite_primary_bar_social', 10 );

// Primary Menu Bar WooCommerce Icons.
if ( ! function_exists( 'magazine_elite_primary_bar_woo_icons' ) ) :
	function magazine_elite_primary_bar_woo_icons() {

		if ( magazine_elite_is_wc_active() ) :

			if ( get_theme_mod( 'enable_woo_my_account_menu_bar', true ) ) :
				$my_account_page = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
				if ( is_user_logged_in() ) :
					?>
					<a href="<?php echo esc_url( $my_account_page ); ?>" class="site-header-account" title="<?php esc_attr_e( 'My Account', 'magazine-elite' ); ?>">
					<?php magazine_elite_the_theme_svg( 'login' ); ?>
					</a>
				<?php else : ?>
					<a href="<?php echo esc_url( $my_account_page ); ?>" class="site-header-account" title="<?php esc_attr_e( 'Login / Register', 'magazine-elite' ); ?>">
					<?php magazine_elite_the_theme_svg( 'login' ); ?>
					</a>
					<?php
				endif;
			endif;

			if ( get_theme_mod( 'enable_woo_mini_cart_menu_bar', true ) ) :
				magazine_elite_woocommerce_header_cart();
			endif;

		endif;
	}
endif;
add_action( 'magazine_elite_secondary_nav_items', 'magazine_elite_primary_bar_woo_icons', 20 );

// Primary Menu Bar Search Icon.
if ( ! function_exists( 'magazine_elite_primary_bar_search' ) ) :
	function magazine_elite_primary_bar_search() {
		if ( get_theme_mod( 'enable_search_on_menu_bar' ) ) :
			$btn_class = '';
			if ( 'style_2' == get_theme_mod( 'header_search_btn_style', 'style_2' ) ) {
				$btn_class = 'toggle ';
			}
			?>
			<div class="magazine-elite-search-toggle">
				<button class="magazine-elite-search-canvas-btn magazine-elite-search search-icon toggle-canvas-modal <?php echo esc_attr( $btn_class ); ?>" aria-expanded="false" data-modal=".magazine-elite-search-block" data-body-class="showing-search-modal" data-focus=".magazine-elite-search-block .search-field">
					<span class="search-label"><?php esc_html_e( 'Search', 'magazine-elite' ); ?></span>
					<?php magazine_elite_the_theme_svg( 'search' ); ?>
				</button>
			</div>
			<?php
		endif;
	}
endif;
add_action( 'magazine_elite_secondary_nav_items', 'magazine_elite_primary_bar_search', 30 );
