<?php
$cat_posts_grid_categories = get_theme_mod( 'cat_posts_grid_categories' );

if ( $cat_posts_grid_categories && ! empty( $cat_posts_grid_categories ) ) :

	$cat_posts_grid_orderby = get_theme_mod( 'cat_posts_grid_orderby', 'date' );
	// Covert id to ID to make it work with query
	if ( 'id' == $cat_posts_grid_orderby ) {
		$cat_posts_grid_orderby = 'ID';
	}

	$item_class = $wrapper_class = '';

	$cat_posts_grid_order       = get_theme_mod( 'cat_posts_grid_order', 'desc' );
	$cat_posts_grid_no_of_posts = get_theme_mod( 'cat_posts_grid_no_of_posts', 4 );
	$cat_posts_grid_post_meta   = get_theme_mod( 'cat_posts_grid_post_meta', array( 'author', 'date' ) );
	$cat_posts_grid_date_format = get_theme_mod( 'cat_posts_grid_date_format', 'format_2' );
	$author_image               = get_theme_mod( 'enable_cat_posts_grid_author_image' );
	$enable_express_desc        = get_theme_mod( 'enable_cat_posts_grid_express_desc' );
	$meta_on_express_only       = get_theme_mod( 'enable_cat_posts_grid_meta_express_only' );
	$enable_post_format_icon    = get_theme_mod( 'enable_cat_posts_grid_post_format_icon' );
	$invert_list_post           = get_theme_mod( 'cat_posts_grid_invert_list_post' );
	if ( $invert_list_post ) {
		$item_class .= ' saga-inverted-item';
	}
	$hide_list_image = get_theme_mod( 'cat_posts_grid_hide_list_post_img' );
	if ( $hide_list_image ) {
		$item_class .= ' saga-hidden-post-image';
	}
	$meta_settings['date_format'] = $cat_posts_grid_date_format;

	// Item Separator.
	$item_separator = get_theme_mod( 'enable_cat_posts_grid_row_separator', true );
	if ( $item_separator ) {
		$wrapper_class .= ' saga-item-sep';
	}

	// Cat Heading.
	$title_style = get_theme_mod( 'cat_posts_grid_title_style', 'style_1' );
	$title_align = get_theme_mod( 'cat_posts_grid_title_align', 'left' );
	$title_class = $title_style . ' has-text-align-' . $title_align;

	$cat_posts_grid_column = get_theme_mod( 'cat_posts_grid_column', 3 );
	$col_class             = 'row row-cols-1 gx-4 gy-5';
	if ( 2 == $cat_posts_grid_column ) {
		$col_class .= ' row-cols-md-2 magazine-elite-grid-2';
	} elseif ( 3 == $cat_posts_grid_column ) {
		$col_class .= ' row-cols-md-2 row-cols-lg-3 magazine-elite-grid-3';
	} elseif ( 4 == $cat_posts_grid_column ) {
		$col_class .= ' row-cols-md-2 row-cols-xl-4 magazine-elite-grid-4';
	} elseif ( 5 == $cat_posts_grid_column ) {
		$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-elite-grid-5';
	} else {
		$col_class .= ' row-cols-md-2 row-cols-lg-3 magazine-elite-grid-3';
	}

	$express_title_limit = get_theme_mod( 'cat_posts_grid_express_title_limit' );
	$list_title_limit    = get_theme_mod( 'cat_posts_grid_list_title_limit' );


	?>
		<section class="magazine-elite-section-block section-categories-posts-grid">
			<div class="wide-max-width">
				<div class="saga-section-content<?php echo esc_attr( $wrapper_class ); ?>">
					<div class="<?php echo esc_attr( $col_class ); ?>">
						<?php

						$item_wrapper_class    = 'article-block-wrapper magazine-elite-card-box img-animate-zoom';
						$image_wrapper_class   = 'article-image';
						$content_wrapper_class = 'article-details';

						foreach ( $cat_posts_grid_categories as $category ) {

							$query_args = array(
								'post_type'           => 'post',
								'posts_per_page'      => $cat_posts_grid_no_of_posts,
								'post_status'         => 'publish',
								'no_found_rows'       => 1,
								'orderby'             => $cat_posts_grid_orderby,
								'order'               => $cat_posts_grid_order,
								'ignore_sticky_posts' => 1,
								'tax_query'           => array(
									array(
										'taxonomy' => 'category',
										'field'    => 'term_id',
										'terms'    => $category,
									),
								),
							);

							$posts_query = new WP_Query( $query_args );

							if ( $posts_query->have_posts() ) {
								$first      = true;
								$show_image = true;

								?>
								<div class="col<?php echo esc_attr( $item_class ); ?>">
									<h3 class="saga-element-header <?php echo esc_attr( $title_class ); ?>">
										<span><?php echo esc_html( get_the_category_by_ID( $category ) ); ?></span>
									</h3>
									<div class="row row-cols-1<?php echo $item_separator ? ' g-5' : ' g-4'; ?>">
										<?php
										while ( $posts_query->have_posts() ) :
											$posts_query->the_post();
											if ( true == $first ) {
												$image_size        = 'magazine-elite-medium-img';
												$col_wrapper_class = 'magazine-elite-express-posts';
												$title_limit       = $express_title_limit;
											} else {
												$image_size        = 'thumbnail';
												$col_wrapper_class = 'magazine-elite-list-posts';
												$title_limit       = $list_title_limit;
												if ( $hide_list_image ) {
													$show_image = false;
												}
											}
											?>
											<div class="col <?php echo esc_attr( $col_wrapper_class ); ?>">
												<div class="<?php echo esc_attr( $item_wrapper_class ); ?>">
													<?php
													if ( has_post_thumbnail() && $show_image ) :
														?>
														<div class="<?php echo esc_attr( $image_wrapper_class ); ?>">
															<a href="<?php the_permalink(); ?>">
																<?php
																if ( $enable_post_format_icon ) {
																	magazine_elite_post_format_icon( 'center' );
																}
																?>
																<?php
																the_post_thumbnail(
																	$image_size,
																	array(
																		'alt' => the_title_attribute(
																			array(
																				'echo' => false,
																			)
																		),
																	)
																);
																?>
															</a>
														</div>
														<?php
													endif;
													?>
													<div class="<?php echo esc_attr( $content_wrapper_class ); ?>">
														<h3 class="article-title no-margin">
															<a href="<?php the_permalink(); ?>" class="text-decoration-none color-accent-hover magazine-elite-limit-lines <?php echo esc_attr( $title_limit ); ?>">
																<?php the_title(); ?>
															</a>
														</h3>
														<?php
														// Author Image.
														if ( $author_image ) {
															if ( true == $first ) {
																$meta_settings['author_image'] = true;
															} else {
																$meta_settings['author_image'] = false;
															}
														}
														// Meta.
														if ( $meta_on_express_only ) {
															if ( true == $first ) {
																magazine_elite_post_meta_info( $cat_posts_grid_post_meta, $meta_settings );
															}
														} else {
															magazine_elite_post_meta_info( $cat_posts_grid_post_meta, $meta_settings );
														}
														// Desc.
														if ( $enable_express_desc && true == $first ) :
															$desc_length = absint( get_theme_mod( 'cat_posts_grid_express_desc_length', 18 ) );
															?>
															<div class="article-excerpt">
																<p class="no-margin">
																	<?php echo wp_trim_words( get_the_excerpt(), $desc_length, '&hellip;' ); ?>
																</p>
															</div>
															<?php
														endif;
														?>
													</div>
												</div>
											</div>
											<?php
											$first = false;
										endwhile;
										wp_reset_postdata();
										?>
									</div>
								</div>
								<?php
							}
						}
						?>
					</div>
				</div>
			</div>
		</section>
	<?php
endif;
