<?php
$featured_categories = get_theme_mod( 'featured_categories' );

if ( $featured_categories && ! empty( $featured_categories ) ) :

	$featured_categories_title  = get_theme_mod( 'featured_categories_title' );
	$featured_categories_column = get_theme_mod( 'featured_categories_column', 4 );
	$enable_desc                = get_theme_mod( 'enable_featured_categories_desc', true );
	$desc_length                = get_theme_mod( 'featured_categories_desc_length', 18 );
	$enable_read_more           = get_theme_mod( 'enable_featured_categories_read_more', true );
	$read_more_text             = get_theme_mod( 'featured_categories_read_more_text' );
	if ( ! $read_more_text ) {
		$read_more_text = __( 'Find out more', 'magazine-elite' );
	}
	$read_more_icon = get_theme_mod( 'featured_categories_read_more_icon', 'arrow-right' );
	$enable_overlay = get_theme_mod( 'enable_featured_categories_overlay', true );
	if ( $enable_overlay ) {
		$overlay_style  = 'background-color:' . esc_attr( get_theme_mod( 'featured_categories_overlay_color', '#000000' ) ) . ';';
		$overlay_style .= 'opacity:' . esc_attr( get_theme_mod( 'featured_categories_overlay_opacity', 0.6 ) ) . ';';
	}
	$desc_style = get_theme_mod( 'featured_categories_desc_display', 'style_1' );

	$col_class = 'row row-cols-1 row-cols-sm-2 g-4';

	if ( 2 == $featured_categories_column ) {
		$col_class .= ' magazine-elite-grid-2';
	} elseif ( 3 == $featured_categories_column ) {
		$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
	} elseif ( 4 == $featured_categories_column ) {
		$col_class .= ' row-cols-xl-4 magazine-elite-grid-4';
	} elseif ( 5 == $featured_categories_column ) {
		$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-elite-grid-5';
	} else {
		$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
	}

	?>
	<section class="magazine-elite-section-block section-featured-categories">
		<div class="wide-max-width">
			<?php
			if ( ! empty( $featured_categories_title ) ) :
				$title_style = get_theme_mod( 'featured_categories_title_style', 'style_2' );
				$title_align = 'has-text-align-' . get_theme_mod( 'featured_categories_title_align', 'left' );
				?>
				<div class="saga-section-title">
					<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
						<span><?php echo esc_html( $featured_categories_title ); ?></span>
					</h2>
				</div>
			<?php endif; ?>
			<div class="saga-section-content">
				<div class="<?php echo esc_attr( $col_class ); ?>">
					<?php
					foreach ( $featured_categories as $category ) {
						$cat_desc = $wrapper_class = '';
						$cat_info = get_category( $category );
						if ( ! empty( $cat_info ) && ! is_wp_error( $cat_info ) ) {
							$term_link        = get_category_link( $category );
							$thumbnail_id     = get_term_meta( $category, 'thumbnail_id', true );
							$image_attributes = wp_get_attachment_image_src( $thumbnail_id, 'magazine-elite-medium-img' );
							if ( $image_attributes ) {
								if ( $enable_desc && $desc_length ) :
									$cat_desc = category_description( $category );
									if ( $cat_desc ) {
										$wrapper_class  = ' has-cat-desc';
										$wrapper_class .= ' cat-desc-display-' . $desc_style;
									}
								endif;
								?>
								<div class="col">
									<div class="saga-block-item-w-overlay img-animate-zoom<?php echo esc_attr( $wrapper_class ); ?>">
										<div class="saga-block-image-w-overlay">
											<?php if ( $enable_overlay ) : ?>
												<span aria-hidden="true" class="magazine-elite-block-overlay" style="<?php echo $overlay_style; ?>"></span>
											<?php endif; ?>
											<img src="<?php echo esc_url( $image_attributes[0] ); ?>" loading="lazy">
										</div>
										<div class="saga-block-overlay-content">
											<h3 class="saga-block-overlay-title">
												<?php echo esc_html( $cat_info->name ); ?>
											</h3>
											<?php if ( $cat_desc ) : ?>
												<div class="category-description">
													<?php echo esc_html( wp_trim_words( $cat_desc, $desc_length, '' ) ); ?>
												</div>
												<?php if ( $enable_read_more ) : ?>
													<div class="category-read-more">
														<span><?php echo esc_html( $read_more_text ); ?></span>
														<span><?php echo magazine_elite_the_theme_svg( $read_more_icon ); ?></span>
													</div>
												<?php endif; ?>
											<?php endif; ?>
										</div>
										<a href="<?php echo esc_url( $term_link ); ?>" class="text-decoration-none">
											<?php echo esc_html( $cat_info->name ); ?>
										</a>
									</div>
								</div>
								<?php
							}
						}
					}
					?>
				</div>
			</div>
		</div>
	</section>
	<?php
endif;
