<?php
$featured_posts_cat     = get_theme_mod( 'featured_posts_cat', 1 );
$featured_posts_orderby = get_theme_mod( 'featured_posts_orderby', 'date' );

// Covert id to ID to make it work with query
if ( 'id' == $featured_posts_orderby ) {
	$featured_posts_orderby = 'ID';
}

$post_args = array(
	'post_type'      => 'post',
	'posts_per_page' => absint( get_theme_mod( 'no_of_featured_posts', 4 ) ),
	'post_status'    => 'publish',
	'orderby'        => esc_attr( $featured_posts_orderby ),
	'order'          => esc_attr( get_theme_mod( 'featured_posts_order', 'desc' ) ),
);

if ( ! empty( $featured_posts_cat ) ) :
	$post_args['tax_query'] = array(
		array(
			'taxonomy' => 'category',
			'field'    => 'term_id',
			'terms'    => $featured_posts_cat,
		),
	);
endif;

$featured_post = new WP_Query( $post_args );
if ( $featured_post->have_posts() ) :

	$featured_posts_title = get_theme_mod( 'featured_posts_title' );
	$enabled_post_meta    = get_theme_mod( 'featured_post_meta', array( 'author', 'date' ) );
	$post_meta_settings   = array(
		'date_format'  => get_theme_mod( 'featured_posts_date_format', 'format_2' ),
		'author_image' => get_theme_mod( 'enable_featured_posts_author_image' ),
	);
	$enable_posts_desc    = get_theme_mod( 'enable_featured_posts_desc' );
	if ( $enable_posts_desc ) {
		$desc_length = absint( get_theme_mod( 'featured_posts_desc_length', 18 ) );
	}
	$featured_posts_column = get_theme_mod( 'featured_posts_column', 4 );
	$show_category         = get_theme_mod( 'show_featured_posts_category' );
	if ( $show_category ) {
		$cat_style = get_theme_mod( 'featured_posts_category_style', 'style_1' );
		$cat_color = get_theme_mod( 'featured_posts_category_color_display', 'none' );
		$cat_limit = get_theme_mod( 'featured_posts_category_limit', 3 );
	}
	$enable_overlay = get_theme_mod( 'enable_featured_posts_overlay' );
	if ( $enable_overlay ) {
		$overlay_style  = 'background-color:' . esc_attr( get_theme_mod( 'featured_posts_overlay_color', '#000000' ) ) . ';';
		$overlay_style .= 'opacity:' . esc_attr( get_theme_mod( 'featured_posts_overlay_opacity', 0.6 ) ) . ';';
	}
	$title_limit           = get_theme_mod( 'featured_posts_title_limit' );
	$show_post_format_icon = get_theme_mod( 'show_featured_posts_post_format_icon' );

	$col_class = 'row row-cols-1 row-cols-sm-2 g-4';

	if ( 2 == $featured_posts_column ) {
		$col_class .= ' magazine-elite-grid-2';
	} elseif ( 3 == $featured_posts_column ) {
		$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
	} elseif ( 4 == $featured_posts_column ) {
		$col_class .= ' row-cols-xl-4 magazine-elite-grid-4';
	} elseif ( 5 == $featured_posts_column ) {
		$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-elite-grid-5';
	} else {
		$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
	}

	?>
	<section class="magazine-elite-section-block section-featured">
		<div class="wide-max-width">
			<?php
			if ( ! empty( $featured_posts_title ) ) :
				$title_style = get_theme_mod( 'featured_posts_title_style', 'style_2' );
				$title_align = 'has-text-align-' . get_theme_mod( 'featured_posts_title_align', 'left' );
				?>
				<div class="saga-section-title">
					<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
						<span><?php echo esc_html( $featured_posts_title ); ?></span>
					</h2>
				</div>
			<?php endif; ?>
			<?php
			if ( get_theme_mod( 'enable_featured_posts_view_all', true ) ) :
				$view_all_txt = get_theme_mod( 'featured_posts_view_all_txt' );
				if ( empty( $view_all_txt ) ) {
					$view_all_txt = __( 'View All', 'magazine-elite' );
				}
				?>
				<div class="saga-inline-heading-wrapper">
					<div class="saga-inline-heading">
						<?php echo esc_html( get_cat_name( $featured_posts_cat ) ); ?>
					</div>
					<span>
						<a href="<?php echo esc_url( get_category_link( $featured_posts_cat ) ); ?>" class="text-decoration-none">
						<?php echo $view_all_txt; ?></a>
					</span>
				</div>
			<?php endif; ?>
			<div class="saga-section-content">
				<div class="<?php echo esc_attr( $col_class ); ?>">
					<?php
					while ( $featured_post->have_posts() ) :
						$featured_post->the_post();
						?>
						<div class="col">
							<div class="saga-block-post-card magazine-elite-card-box img-animate-zoom">
								<div class="saga-block-item-w-overlay">
									<div class="saga-block-image-w-overlay">
										<a href="<?php the_permalink(); ?>" class="">
											<?php
											if ( $show_post_format_icon ) :
												magazine_elite_post_format_icon( 'center' );
											endif;
											?>
											<?php if ( $enable_overlay ) : ?>
												<span aria-hidden="true" class="magazine-elite-block-overlay" style="<?php echo $overlay_style; ?>"></span>
												<?php endif; ?>
											<?php the_post_thumbnail( 'magazine-elite-medium-img' ); ?>
										</a>
									</div>
									<div class="saga-block-overlay-content">
										<?php
										if ( $show_category ) :
											magazine_elite_post_categories( $cat_style, $cat_color, $cat_limit );
										endif;
										?>
									</div>
								</div>
								<div class="saga-block-card-content">
									<h3 class="saga-block-card-title no-margin">
										<a href="<?php the_permalink(); ?>" class="text-decoration-none color-accent-hover  magazine-elite-limit-lines <?php echo esc_attr( $title_limit ); ?>">
											<?php the_title(); ?>
										</a>
									</h3>
									<?php magazine_elite_post_meta_info( $enabled_post_meta, $post_meta_settings ); ?>
									<?php if ( $enable_posts_desc ) : ?>
										<div class="saga-block-card-desc">
											<?php echo wp_trim_words( get_the_excerpt(), $desc_length, '&hellip;' ); ?>
										</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
						<?php
					endwhile;
					wp_reset_postdata();
					?>
				</div>
			</div>
		</div>
	</section>
	<?php
endif;
