<?php
$trending_posts_cat     = get_theme_mod( 'trending_posts_cat', 1 );
$trending_posts_orderby = get_theme_mod( 'trending_posts_orderby', 'date' );

// Covert id to ID to make it work with query
if ( 'id' == $trending_posts_orderby ) {
	$trending_posts_orderby = 'ID';
}

if ( ! empty( $trending_posts_cat ) ) :
	$post_args = array(
		'post_type'      => 'post',
		'posts_per_page' => absint( get_theme_mod( 'no_of_trending_posts', 3 ) ),
		'post_status'    => 'publish',
		'orderby'        => esc_attr( $trending_posts_orderby ),
		'order'          => esc_attr( get_theme_mod( 'trending_posts_order', 'desc' ) ),
		'tax_query'      => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'term_id',
				'terms'    => $trending_posts_cat,
			),
		),

	);
	$trending_post = new WP_Query( $post_args );
	if ( $trending_post->have_posts() ) :

		$trending_posts_title  = get_theme_mod( 'trending_posts_title', __( 'Trending Now', 'magazine-elite' ) );
		$trending_posts_column = get_theme_mod( 'trending_posts_column', 3 );
		$show_category         = get_theme_mod( 'show_trending_posts_category', true );
		if ( $show_category ) {
			$cat_style = get_theme_mod( 'trending_posts_category_style', 'style_1' );
			$cat_color = get_theme_mod( 'trending_posts_category_color_display', 'none' );
			$cat_limit = get_theme_mod( 'trending_posts_category_limit', 3 );
		}
		$trending_post_meta          = get_theme_mod( 'trending_post_meta' );
		$trending_post_meta_settings = array(
			'date_format'  => get_theme_mod( 'trending_posts_date_format', 'format_2' ),
			'author_image' => get_theme_mod( 'enable_trending_posts_author_image' ),
		);
		$enable_overlay              = get_theme_mod( 'enable_trending_posts_overlay', true );
		if ( $enable_overlay ) {
			$overlay_style  = 'background-color:' . esc_attr( get_theme_mod( 'trending_posts_overlay_color', '#000000' ) ) . ';';
			$overlay_style .= 'opacity:' . esc_attr( get_theme_mod( 'trending_posts_overlay_opacity', 0.6 ) ) . ';';
		}
		$title_limit = get_theme_mod( 'trending_posts_title_limit' );

		$col_class = 'row row-cols-1 row-cols-sm-2 g-3';

		if ( 2 == $trending_posts_column ) {
			$col_class .= ' row-cols-md-2 row-cols-lg-2 magazine-elite-grid-2';
		} elseif ( 3 == $trending_posts_column ) {
			$col_class .= ' row-cols-md-3 row-cols-lg-3 magazine-elite-grid-3';
		} elseif ( 4 == $trending_posts_column ) {
			$col_class .= ' row-cols-lg-4 magazine-elite-grid-4';
		} elseif ( 5 == $trending_posts_column ) {
			$col_class .= ' row-cols-md-3 row-cols-xl-5 magazine-elite-grid-5';
		} else {
			$col_class .= ' row-cols-lg-3 magazine-elite-grid-3';
		}
		?>
		<section class="magazine-elite-section-block section-trending">
			<div class="wide-max-width">
				<?php
				if ( ! empty( $trending_posts_title ) ) :
					$title_style = get_theme_mod( 'trending_posts_title_style', 'style_1' );
					$title_align = 'has-text-align-' . get_theme_mod( 'trending_posts_title_align', 'left' );
					?>
					<div class="saga-section-title">
						<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
							<span><?php echo esc_html( $trending_posts_title ); ?></span>
						</h2>
					</div>
				<?php endif; ?>
				<div class="saga-section-content">
					<div class="<?php echo esc_attr( $col_class ); ?>">
						<?php
						while ( $trending_post->have_posts() ) :
							$trending_post->the_post();
							if ( has_post_thumbnail() ) :
								?>
								<div class="col">
									<div class="saga-block-item-w-overlay img-animate-zoom">
										<div class="saga-block-image-w-overlay">
											<a href="<?php the_permalink(); ?>" class="">
												<?php
												if ( get_theme_mod( 'show_trending_posts_post_format_icon' ) ) {
													magazine_elite_post_format_icon();
												}
												?>
												<?php if ( $enable_overlay ) : ?>
													<span aria-hidden="true" class="magazine-elite-block-overlay" style="<?php echo $overlay_style; ?>"></span>
												<?php endif; ?>
												<?php the_post_thumbnail( 'magazine-elite-large-img' ); ?>
											</a>
										</div>
										<div class="saga-block-overlay-content">
											<?php
											if ( $show_category ) :
												magazine_elite_post_categories( $cat_style, $cat_color, $cat_limit );
											endif;
											?>
											<h3 class="saga-block-overlay-title">
												<a href="<?php the_permalink(); ?>" class="text-decoration-none magazine-elite-limit-lines <?php echo esc_attr( $title_limit ); ?>">
													<?php the_title(); ?>
												</a>
											</h3>
											<?php magazine_elite_post_meta_info( $trending_post_meta, $trending_post_meta_settings ); ?>
										</div>
									</div>
								</div>
								<?php
							endif;
						endwhile;
						wp_reset_postdata();
						?>
					</div>
				</div>
			</div>
		</section>
		<?php
	endif;
endif;
